// Code generated by 'yaegi extract syscall'. DO NOT EDIT.

//go:build go1.21 && !go1.22
// +build go1.21,!go1.22

package syscall

import (
	"go/constant"
	"go/token"
	"reflect"
	"syscall"
)

func init() {
	Symbols["syscall/syscall"] = map[string]reflect.Value{
		// function, constant and variable definitions
		"AF_ALG":                            reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"AF_APPLETALK":                      reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"AF_ASH":                            reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"AF_ATMPVC":                         reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"AF_ATMSVC":                         reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"AF_AX25":                           reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"AF_BLUETOOTH":                      reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"AF_BRIDGE":                         reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"AF_CAIF":                           reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"AF_CAN":                            reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"AF_DECnet":                         reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"AF_ECONET":                         reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"AF_FILE":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"AF_IB":                             reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"AF_IEEE802154":                     reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"AF_INET":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"AF_INET6":                          reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"AF_IPX":                            reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"AF_IRDA":                           reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"AF_ISDN":                           reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"AF_IUCV":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"AF_KCM":                            reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"AF_KEY":                            reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"AF_LLC":                            reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"AF_LOCAL":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"AF_MAX":                            reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"AF_MCTP":                           reflect.ValueOf(constant.MakeFromLiteral("45", token.INT, 0)),
		"AF_MPLS":                           reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"AF_NETBEUI":                        reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"AF_NETLINK":                        reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"AF_NETROM":                         reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"AF_NFC":                            reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"AF_PACKET":                         reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"AF_PHONET":                         reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"AF_PPPOX":                          reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"AF_QIPCRTR":                        reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"AF_RDS":                            reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"AF_ROSE":                           reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"AF_ROUTE":                          reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"AF_RXRPC":                          reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"AF_SECURITY":                       reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"AF_SMC":                            reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"AF_SNA":                            reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"AF_TIPC":                           reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"AF_UNIX":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"AF_UNSPEC":                         reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"AF_VSOCK":                          reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"AF_WANPIPE":                        reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"AF_X25":                            reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"AF_XDP":                            reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"ARPHRD_6LOWPAN":                    reflect.ValueOf(constant.MakeFromLiteral("825", token.INT, 0)),
		"ARPHRD_ADAPT":                      reflect.ValueOf(constant.MakeFromLiteral("264", token.INT, 0)),
		"ARPHRD_APPLETLK":                   reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"ARPHRD_ARCNET":                     reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"ARPHRD_ASH":                        reflect.ValueOf(constant.MakeFromLiteral("781", token.INT, 0)),
		"ARPHRD_ATM":                        reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"ARPHRD_AX25":                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"ARPHRD_BIF":                        reflect.ValueOf(constant.MakeFromLiteral("775", token.INT, 0)),
		"ARPHRD_CAIF":                       reflect.ValueOf(constant.MakeFromLiteral("822", token.INT, 0)),
		"ARPHRD_CAN":                        reflect.ValueOf(constant.MakeFromLiteral("280", token.INT, 0)),
		"ARPHRD_CHAOS":                      reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"ARPHRD_CISCO":                      reflect.ValueOf(constant.MakeFromLiteral("513", token.INT, 0)),
		"ARPHRD_CSLIP":                      reflect.ValueOf(constant.MakeFromLiteral("257", token.INT, 0)),
		"ARPHRD_CSLIP6":                     reflect.ValueOf(constant.MakeFromLiteral("259", token.INT, 0)),
		"ARPHRD_DDCMP":                      reflect.ValueOf(constant.MakeFromLiteral("517", token.INT, 0)),
		"ARPHRD_DLCI":                       reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"ARPHRD_ECONET":                     reflect.ValueOf(constant.MakeFromLiteral("782", token.INT, 0)),
		"ARPHRD_EETHER":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"ARPHRD_ETHER":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"ARPHRD_EUI64":                      reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"ARPHRD_FCAL":                       reflect.ValueOf(constant.MakeFromLiteral("785", token.INT, 0)),
		"ARPHRD_FCFABRIC":                   reflect.ValueOf(constant.MakeFromLiteral("787", token.INT, 0)),
		"ARPHRD_FCPL":                       reflect.ValueOf(constant.MakeFromLiteral("786", token.INT, 0)),
		"ARPHRD_FCPP":                       reflect.ValueOf(constant.MakeFromLiteral("784", token.INT, 0)),
		"ARPHRD_FDDI":                       reflect.ValueOf(constant.MakeFromLiteral("774", token.INT, 0)),
		"ARPHRD_FRAD":                       reflect.ValueOf(constant.MakeFromLiteral("770", token.INT, 0)),
		"ARPHRD_HDLC":                       reflect.ValueOf(constant.MakeFromLiteral("513", token.INT, 0)),
		"ARPHRD_HIPPI":                      reflect.ValueOf(constant.MakeFromLiteral("780", token.INT, 0)),
		"ARPHRD_HWX25":                      reflect.ValueOf(constant.MakeFromLiteral("272", token.INT, 0)),
		"ARPHRD_IEEE1394":                   reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"ARPHRD_IEEE802":                    reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"ARPHRD_IEEE80211":                  reflect.ValueOf(constant.MakeFromLiteral("801", token.INT, 0)),
		"ARPHRD_IEEE80211_PRISM":            reflect.ValueOf(constant.MakeFromLiteral("802", token.INT, 0)),
		"ARPHRD_IEEE80211_RADIOTAP":         reflect.ValueOf(constant.MakeFromLiteral("803", token.INT, 0)),
		"ARPHRD_IEEE802154":                 reflect.ValueOf(constant.MakeFromLiteral("804", token.INT, 0)),
		"ARPHRD_IEEE802154_MONITOR":         reflect.ValueOf(constant.MakeFromLiteral("805", token.INT, 0)),
		"ARPHRD_IEEE802_TR":                 reflect.ValueOf(constant.MakeFromLiteral("800", token.INT, 0)),
		"ARPHRD_INFINIBAND":                 reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"ARPHRD_IP6GRE":                     reflect.ValueOf(constant.MakeFromLiteral("823", token.INT, 0)),
		"ARPHRD_IPDDP":                      reflect.ValueOf(constant.MakeFromLiteral("777", token.INT, 0)),
		"ARPHRD_IPGRE":                      reflect.ValueOf(constant.MakeFromLiteral("778", token.INT, 0)),
		"ARPHRD_IRDA":                       reflect.ValueOf(constant.MakeFromLiteral("783", token.INT, 0)),
		"ARPHRD_LAPB":                       reflect.ValueOf(constant.MakeFromLiteral("516", token.INT, 0)),
		"ARPHRD_LOCALTLK":                   reflect.ValueOf(constant.MakeFromLiteral("773", token.INT, 0)),
		"ARPHRD_LOOPBACK":                   reflect.ValueOf(constant.MakeFromLiteral("772", token.INT, 0)),
		"ARPHRD_MCTP":                       reflect.ValueOf(constant.MakeFromLiteral("290", token.INT, 0)),
		"ARPHRD_METRICOM":                   reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"ARPHRD_NETLINK":                    reflect.ValueOf(constant.MakeFromLiteral("824", token.INT, 0)),
		"ARPHRD_NETROM":                     reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"ARPHRD_NONE":                       reflect.ValueOf(constant.MakeFromLiteral("65534", token.INT, 0)),
		"ARPHRD_PHONET":                     reflect.ValueOf(constant.MakeFromLiteral("820", token.INT, 0)),
		"ARPHRD_PHONET_PIPE":                reflect.ValueOf(constant.MakeFromLiteral("821", token.INT, 0)),
		"ARPHRD_PIMREG":                     reflect.ValueOf(constant.MakeFromLiteral("779", token.INT, 0)),
		"ARPHRD_PPP":                        reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"ARPHRD_PRONET":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"ARPHRD_RAWHDLC":                    reflect.ValueOf(constant.MakeFromLiteral("518", token.INT, 0)),
		"ARPHRD_RAWIP":                      reflect.ValueOf(constant.MakeFromLiteral("519", token.INT, 0)),
		"ARPHRD_ROSE":                       reflect.ValueOf(constant.MakeFromLiteral("270", token.INT, 0)),
		"ARPHRD_RSRVD":                      reflect.ValueOf(constant.MakeFromLiteral("260", token.INT, 0)),
		"ARPHRD_SIT":                        reflect.ValueOf(constant.MakeFromLiteral("776", token.INT, 0)),
		"ARPHRD_SKIP":                       reflect.ValueOf(constant.MakeFromLiteral("771", token.INT, 0)),
		"ARPHRD_SLIP":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"ARPHRD_SLIP6":                      reflect.ValueOf(constant.MakeFromLiteral("258", token.INT, 0)),
		"ARPHRD_TUNNEL":                     reflect.ValueOf(constant.MakeFromLiteral("768", token.INT, 0)),
		"ARPHRD_TUNNEL6":                    reflect.ValueOf(constant.MakeFromLiteral("769", token.INT, 0)),
		"ARPHRD_VOID":                       reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"ARPHRD_VSOCKMON":                   reflect.ValueOf(constant.MakeFromLiteral("826", token.INT, 0)),
		"ARPHRD_X25":                        reflect.ValueOf(constant.MakeFromLiteral("271", token.INT, 0)),
		"Accept":                            reflect.ValueOf(syscall.Accept),
		"Accept4":                           reflect.ValueOf(syscall.Accept4),
		"Access":                            reflect.ValueOf(syscall.Access),
		"Acct":                              reflect.ValueOf(syscall.Acct),
		"Adjtimex":                          reflect.ValueOf(syscall.Adjtimex),
		"AttachLsf":                         reflect.ValueOf(syscall.AttachLsf),
		"B0":                                reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"B1000000":                          reflect.ValueOf(constant.MakeFromLiteral("4104", token.INT, 0)),
		"B110":                              reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"B115200":                           reflect.ValueOf(constant.MakeFromLiteral("4098", token.INT, 0)),
		"B1152000":                          reflect.ValueOf(constant.MakeFromLiteral("4105", token.INT, 0)),
		"B1200":                             reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"B134":                              reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"B150":                              reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"B1500000":                          reflect.ValueOf(constant.MakeFromLiteral("4106", token.INT, 0)),
		"B1800":                             reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"B19200":                            reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"B200":                              reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"B2000000":                          reflect.ValueOf(constant.MakeFromLiteral("4107", token.INT, 0)),
		"B230400":                           reflect.ValueOf(constant.MakeFromLiteral("4099", token.INT, 0)),
		"B2400":                             reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"B2500000":                          reflect.ValueOf(constant.MakeFromLiteral("4108", token.INT, 0)),
		"B300":                              reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"B3000000":                          reflect.ValueOf(constant.MakeFromLiteral("4109", token.INT, 0)),
		"B3500000":                          reflect.ValueOf(constant.MakeFromLiteral("4110", token.INT, 0)),
		"B38400":                            reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"B4000000":                          reflect.ValueOf(constant.MakeFromLiteral("4111", token.INT, 0)),
		"B460800":                           reflect.ValueOf(constant.MakeFromLiteral("4100", token.INT, 0)),
		"B4800":                             reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"B50":                               reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"B500000":                           reflect.ValueOf(constant.MakeFromLiteral("4101", token.INT, 0)),
		"B57600":                            reflect.ValueOf(constant.MakeFromLiteral("4097", token.INT, 0)),
		"B576000":                           reflect.ValueOf(constant.MakeFromLiteral("4102", token.INT, 0)),
		"B600":                              reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"B75":                               reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"B921600":                           reflect.ValueOf(constant.MakeFromLiteral("4103", token.INT, 0)),
		"B9600":                             reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"BPF_A":                             reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_ABS":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"BPF_ADD":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_ALU":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"BPF_AND":                           reflect.ValueOf(constant.MakeFromLiteral("80", token.INT, 0)),
		"BPF_B":                             reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_DIV":                           reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"BPF_H":                             reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"BPF_IMM":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_IND":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"BPF_JA":                            reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_JEQ":                           reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_JGE":                           reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"BPF_JGT":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"BPF_JMP":                           reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"BPF_JSET":                          reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"BPF_K":                             reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_LD":                            reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_LDX":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"BPF_LEN":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"BPF_LL_OFF":                        reflect.ValueOf(constant.MakeFromLiteral("-2097152", token.INT, 0)),
		"BPF_LSH":                           reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"BPF_MAJOR_VERSION":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"BPF_MAXINSNS":                      reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"BPF_MEM":                           reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"BPF_MEMWORDS":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_MINOR_VERSION":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"BPF_MISC":                          reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"BPF_MOD":                           reflect.ValueOf(constant.MakeFromLiteral("144", token.INT, 0)),
		"BPF_MSH":                           reflect.ValueOf(constant.MakeFromLiteral("160", token.INT, 0)),
		"BPF_MUL":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"BPF_NEG":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"BPF_NET_OFF":                       reflect.ValueOf(constant.MakeFromLiteral("-1048576", token.INT, 0)),
		"BPF_OR":                            reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"BPF_RET":                           reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"BPF_RSH":                           reflect.ValueOf(constant.MakeFromLiteral("112", token.INT, 0)),
		"BPF_ST":                            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"BPF_STX":                           reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"BPF_SUB":                           reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_TAX":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_TXA":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"BPF_W":                             reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_X":                             reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"BPF_XOR":                           reflect.ValueOf(constant.MakeFromLiteral("160", token.INT, 0)),
		"BRKINT":                            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"Bind":                              reflect.ValueOf(syscall.Bind),
		"BindToDevice":                      reflect.ValueOf(syscall.BindToDevice),
		"BytePtrFromString":                 reflect.ValueOf(syscall.BytePtrFromString),
		"ByteSliceFromString":               reflect.ValueOf(syscall.ByteSliceFromString),
		"CFLUSH":                            reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"CLOCAL":                            reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"CLONE_ARGS_SIZE_VER0":              reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"CLONE_ARGS_SIZE_VER1":              reflect.ValueOf(constant.MakeFromLiteral("80", token.INT, 0)),
		"CLONE_ARGS_SIZE_VER2":              reflect.ValueOf(constant.MakeFromLiteral("88", token.INT, 0)),
		"CLONE_CHILD_CLEARTID":              reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"CLONE_CHILD_SETTID":                reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"CLONE_CLEAR_SIGHAND":               reflect.ValueOf(constant.MakeFromLiteral("4294967296", token.INT, 0)),
		"CLONE_DETACHED":                    reflect.ValueOf(constant.MakeFromLiteral("4194304", token.INT, 0)),
		"CLONE_FILES":                       reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"CLONE_FS":                          reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"CLONE_INTO_CGROUP":                 reflect.ValueOf(constant.MakeFromLiteral("8589934592", token.INT, 0)),
		"CLONE_IO":                          reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"CLONE_NEWCGROUP":                   reflect.ValueOf(constant.MakeFromLiteral("33554432", token.INT, 0)),
		"CLONE_NEWIPC":                      reflect.ValueOf(constant.MakeFromLiteral("134217728", token.INT, 0)),
		"CLONE_NEWNET":                      reflect.ValueOf(constant.MakeFromLiteral("1073741824", token.INT, 0)),
		"CLONE_NEWNS":                       reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"CLONE_NEWPID":                      reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"CLONE_NEWTIME":                     reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"CLONE_NEWUSER":                     reflect.ValueOf(constant.MakeFromLiteral("268435456", token.INT, 0)),
		"CLONE_NEWUTS":                      reflect.ValueOf(constant.MakeFromLiteral("67108864", token.INT, 0)),
		"CLONE_PARENT":                      reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"CLONE_PARENT_SETTID":               reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"CLONE_PIDFD":                       reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"CLONE_PTRACE":                      reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"CLONE_SETTLS":                      reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"CLONE_SIGHAND":                     reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"CLONE_SYSVSEM":                     reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"CLONE_THREAD":                      reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"CLONE_UNTRACED":                    reflect.ValueOf(constant.MakeFromLiteral("8388608", token.INT, 0)),
		"CLONE_VFORK":                       reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"CLONE_VM":                          reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"CREAD":                             reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"CS5":                               reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"CS6":                               reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"CS7":                               reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"CS8":                               reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"CSIGNAL":                           reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"CSIZE":                             reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"CSTART":                            reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"CSTATUS":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"CSTOP":                             reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"CSTOPB":                            reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"CSUSP":                             reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"Chdir":                             reflect.ValueOf(syscall.Chdir),
		"Chmod":                             reflect.ValueOf(syscall.Chmod),
		"Chown":                             reflect.ValueOf(syscall.Chown),
		"Chroot":                            reflect.ValueOf(syscall.Chroot),
		"Clearenv":                          reflect.ValueOf(syscall.Clearenv),
		"Close":                             reflect.ValueOf(syscall.Close),
		"CloseOnExec":                       reflect.ValueOf(syscall.CloseOnExec),
		"CmsgLen":                           reflect.ValueOf(syscall.CmsgLen),
		"CmsgSpace":                         reflect.ValueOf(syscall.CmsgSpace),
		"Connect":                           reflect.ValueOf(syscall.Connect),
		"Creat":                             reflect.ValueOf(syscall.Creat),
		"DT_BLK":                            reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"DT_CHR":                            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"DT_DIR":                            reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"DT_FIFO":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"DT_LNK":                            reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"DT_REG":                            reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"DT_SOCK":                           reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"DT_UNKNOWN":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"DT_WHT":                            reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"DetachLsf":                         reflect.ValueOf(syscall.DetachLsf),
		"Dup":                               reflect.ValueOf(syscall.Dup),
		"Dup3":                              reflect.ValueOf(syscall.Dup3),
		"E2BIG":                             reflect.ValueOf(syscall.E2BIG),
		"EACCES":                            reflect.ValueOf(syscall.EACCES),
		"EADDRINUSE":                        reflect.ValueOf(syscall.EADDRINUSE),
		"EADDRNOTAVAIL":                     reflect.ValueOf(syscall.EADDRNOTAVAIL),
		"EADV":                              reflect.ValueOf(syscall.EADV),
		"EAFNOSUPPORT":                      reflect.ValueOf(syscall.EAFNOSUPPORT),
		"EAGAIN":                            reflect.ValueOf(syscall.EAGAIN),
		"EALREADY":                          reflect.ValueOf(syscall.EALREADY),
		"EBADE":                             reflect.ValueOf(syscall.EBADE),
		"EBADF":                             reflect.ValueOf(syscall.EBADF),
		"EBADFD":                            reflect.ValueOf(syscall.EBADFD),
		"EBADMSG":                           reflect.ValueOf(syscall.EBADMSG),
		"EBADR":                             reflect.ValueOf(syscall.EBADR),
		"EBADRQC":                           reflect.ValueOf(syscall.EBADRQC),
		"EBADSLT":                           reflect.ValueOf(syscall.EBADSLT),
		"EBFONT":                            reflect.ValueOf(syscall.EBFONT),
		"EBUSY":                             reflect.ValueOf(syscall.EBUSY),
		"ECANCELED":                         reflect.ValueOf(syscall.ECANCELED),
		"ECHILD":                            reflect.ValueOf(syscall.ECHILD),
		"ECHO":                              reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"ECHOCTL":                           reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"ECHOE":                             reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"ECHOK":                             reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"ECHOKE":                            reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"ECHONL":                            reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"ECHOPRT":                           reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"ECHRNG":                            reflect.ValueOf(syscall.ECHRNG),
		"ECOMM":                             reflect.ValueOf(syscall.ECOMM),
		"ECONNABORTED":                      reflect.ValueOf(syscall.ECONNABORTED),
		"ECONNREFUSED":                      reflect.ValueOf(syscall.ECONNREFUSED),
		"ECONNRESET":                        reflect.ValueOf(syscall.ECONNRESET),
		"EDEADLK":                           reflect.ValueOf(syscall.EDEADLK),
		"EDEADLOCK":                         reflect.ValueOf(syscall.EDEADLOCK),
		"EDESTADDRREQ":                      reflect.ValueOf(syscall.EDESTADDRREQ),
		"EDOM":                              reflect.ValueOf(syscall.EDOM),
		"EDOTDOT":                           reflect.ValueOf(syscall.EDOTDOT),
		"EDQUOT":                            reflect.ValueOf(syscall.EDQUOT),
		"EEXIST":                            reflect.ValueOf(syscall.EEXIST),
		"EFAULT":                            reflect.ValueOf(syscall.EFAULT),
		"EFBIG":                             reflect.ValueOf(syscall.EFBIG),
		"EHOSTDOWN":                         reflect.ValueOf(syscall.EHOSTDOWN),
		"EHOSTUNREACH":                      reflect.ValueOf(syscall.EHOSTUNREACH),
		"EHWPOISON":                         reflect.ValueOf(syscall.EHWPOISON),
		"EIDRM":                             reflect.ValueOf(syscall.EIDRM),
		"EILSEQ":                            reflect.ValueOf(syscall.EILSEQ),
		"EINPROGRESS":                       reflect.ValueOf(syscall.EINPROGRESS),
		"EINTR":                             reflect.ValueOf(syscall.EINTR),
		"EINVAL":                            reflect.ValueOf(syscall.EINVAL),
		"EIO":                               reflect.ValueOf(syscall.EIO),
		"EISCONN":                           reflect.ValueOf(syscall.EISCONN),
		"EISDIR":                            reflect.ValueOf(syscall.EISDIR),
		"EISNAM":                            reflect.ValueOf(syscall.EISNAM),
		"EKEYEXPIRED":                       reflect.ValueOf(syscall.EKEYEXPIRED),
		"EKEYREJECTED":                      reflect.ValueOf(syscall.EKEYREJECTED),
		"EKEYREVOKED":                       reflect.ValueOf(syscall.EKEYREVOKED),
		"EL2HLT":                            reflect.ValueOf(syscall.EL2HLT),
		"EL2NSYNC":                          reflect.ValueOf(syscall.EL2NSYNC),
		"EL3HLT":                            reflect.ValueOf(syscall.EL3HLT),
		"EL3RST":                            reflect.ValueOf(syscall.EL3RST),
		"ELIBACC":                           reflect.ValueOf(syscall.ELIBACC),
		"ELIBBAD":                           reflect.ValueOf(syscall.ELIBBAD),
		"ELIBEXEC":                          reflect.ValueOf(syscall.ELIBEXEC),
		"ELIBMAX":                           reflect.ValueOf(syscall.ELIBMAX),
		"ELIBSCN":                           reflect.ValueOf(syscall.ELIBSCN),
		"ELNRNG":                            reflect.ValueOf(syscall.ELNRNG),
		"ELOOP":                             reflect.ValueOf(syscall.ELOOP),
		"EMEDIUMTYPE":                       reflect.ValueOf(syscall.EMEDIUMTYPE),
		"EMFILE":                            reflect.ValueOf(syscall.EMFILE),
		"EMLINK":                            reflect.ValueOf(syscall.EMLINK),
		"EMSGSIZE":                          reflect.ValueOf(syscall.EMSGSIZE),
		"EMULTIHOP":                         reflect.ValueOf(syscall.EMULTIHOP),
		"ENAMETOOLONG":                      reflect.ValueOf(syscall.ENAMETOOLONG),
		"ENAVAIL":                           reflect.ValueOf(syscall.ENAVAIL),
		"ENCODING_DEFAULT":                  reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"ENCODING_FM_MARK":                  reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"ENCODING_FM_SPACE":                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"ENCODING_MANCHESTER":               reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"ENCODING_NRZ":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"ENCODING_NRZI":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"ENETDOWN":                          reflect.ValueOf(syscall.ENETDOWN),
		"ENETRESET":                         reflect.ValueOf(syscall.ENETRESET),
		"ENETUNREACH":                       reflect.ValueOf(syscall.ENETUNREACH),
		"ENFILE":                            reflect.ValueOf(syscall.ENFILE),
		"ENOANO":                            reflect.ValueOf(syscall.ENOANO),
		"ENOBUFS":                           reflect.ValueOf(syscall.ENOBUFS),
		"ENOCSI":                            reflect.ValueOf(syscall.ENOCSI),
		"ENODATA":                           reflect.ValueOf(syscall.ENODATA),
		"ENODEV":                            reflect.ValueOf(syscall.ENODEV),
		"ENOENT":                            reflect.ValueOf(syscall.ENOENT),
		"ENOEXEC":                           reflect.ValueOf(syscall.ENOEXEC),
		"ENOKEY":                            reflect.ValueOf(syscall.ENOKEY),
		"ENOLCK":                            reflect.ValueOf(syscall.ENOLCK),
		"ENOLINK":                           reflect.ValueOf(syscall.ENOLINK),
		"ENOMEDIUM":                         reflect.ValueOf(syscall.ENOMEDIUM),
		"ENOMEM":                            reflect.ValueOf(syscall.ENOMEM),
		"ENOMSG":                            reflect.ValueOf(syscall.ENOMSG),
		"ENONET":                            reflect.ValueOf(syscall.ENONET),
		"ENOPKG":                            reflect.ValueOf(syscall.ENOPKG),
		"ENOPROTOOPT":                       reflect.ValueOf(syscall.ENOPROTOOPT),
		"ENOSPC":                            reflect.ValueOf(syscall.ENOSPC),
		"ENOSR":                             reflect.ValueOf(syscall.ENOSR),
		"ENOSTR":                            reflect.ValueOf(syscall.ENOSTR),
		"ENOSYS":                            reflect.ValueOf(syscall.ENOSYS),
		"ENOTBLK":                           reflect.ValueOf(syscall.ENOTBLK),
		"ENOTCONN":                          reflect.ValueOf(syscall.ENOTCONN),
		"ENOTDIR":                           reflect.ValueOf(syscall.ENOTDIR),
		"ENOTEMPTY":                         reflect.ValueOf(syscall.ENOTEMPTY),
		"ENOTNAM":                           reflect.ValueOf(syscall.ENOTNAM),
		"ENOTRECOVERABLE":                   reflect.ValueOf(syscall.ENOTRECOVERABLE),
		"ENOTSOCK":                          reflect.ValueOf(syscall.ENOTSOCK),
		"ENOTSUP":                           reflect.ValueOf(syscall.ENOTSUP),
		"ENOTTY":                            reflect.ValueOf(syscall.ENOTTY),
		"ENOTUNIQ":                          reflect.ValueOf(syscall.ENOTUNIQ),
		"ENXIO":                             reflect.ValueOf(syscall.ENXIO),
		"EOPNOTSUPP":                        reflect.ValueOf(syscall.EOPNOTSUPP),
		"EOVERFLOW":                         reflect.ValueOf(syscall.EOVERFLOW),
		"EOWNERDEAD":                        reflect.ValueOf(syscall.EOWNERDEAD),
		"EPERM":                             reflect.ValueOf(syscall.EPERM),
		"EPFNOSUPPORT":                      reflect.ValueOf(syscall.EPFNOSUPPORT),
		"EPIPE":                             reflect.ValueOf(syscall.EPIPE),
		"EPOLLERR":                          reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"EPOLLET":                           reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"EPOLLEXCLUSIVE":                    reflect.ValueOf(constant.MakeFromLiteral("268435456", token.INT, 0)),
		"EPOLLHUP":                          reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"EPOLLIN":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"EPOLLMSG":                          reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"EPOLLONESHOT":                      reflect.ValueOf(constant.MakeFromLiteral("1073741824", token.INT, 0)),
		"EPOLLOUT":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"EPOLLPRI":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"EPOLLRDBAND":                       reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"EPOLLRDHUP":                        reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"EPOLLRDNORM":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"EPOLLWAKEUP":                       reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"EPOLLWRBAND":                       reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"EPOLLWRNORM":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"EPOLL_CLOEXEC":                     reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"EPOLL_CTL_ADD":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"EPOLL_CTL_DEL":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"EPOLL_CTL_MOD":                     reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"EPROTO":                            reflect.ValueOf(syscall.EPROTO),
		"EPROTONOSUPPORT":                   reflect.ValueOf(syscall.EPROTONOSUPPORT),
		"EPROTOTYPE":                        reflect.ValueOf(syscall.EPROTOTYPE),
		"ERANGE":                            reflect.ValueOf(syscall.ERANGE),
		"EREMCHG":                           reflect.ValueOf(syscall.EREMCHG),
		"EREMOTE":                           reflect.ValueOf(syscall.EREMOTE),
		"EREMOTEIO":                         reflect.ValueOf(syscall.EREMOTEIO),
		"ERESTART":                          reflect.ValueOf(syscall.ERESTART),
		"ERFKILL":                           reflect.ValueOf(syscall.ERFKILL),
		"EROFS":                             reflect.ValueOf(syscall.EROFS),
		"ESHUTDOWN":                         reflect.ValueOf(syscall.ESHUTDOWN),
		"ESOCKTNOSUPPORT":                   reflect.ValueOf(syscall.ESOCKTNOSUPPORT),
		"ESPIPE":                            reflect.ValueOf(syscall.ESPIPE),
		"ESRCH":                             reflect.ValueOf(syscall.ESRCH),
		"ESRMNT":                            reflect.ValueOf(syscall.ESRMNT),
		"ESTALE":                            reflect.ValueOf(syscall.ESTALE),
		"ESTRPIPE":                          reflect.ValueOf(syscall.ESTRPIPE),
		"ETH_P_1588":                        reflect.ValueOf(constant.MakeFromLiteral("35063", token.INT, 0)),
		"ETH_P_8021AD":                      reflect.ValueOf(constant.MakeFromLiteral("34984", token.INT, 0)),
		"ETH_P_8021AH":                      reflect.ValueOf(constant.MakeFromLiteral("35047", token.INT, 0)),
		"ETH_P_8021Q":                       reflect.ValueOf(constant.MakeFromLiteral("33024", token.INT, 0)),
		"ETH_P_80221":                       reflect.ValueOf(constant.MakeFromLiteral("35095", token.INT, 0)),
		"ETH_P_802_2":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"ETH_P_802_3":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"ETH_P_802_3_MIN":                   reflect.ValueOf(constant.MakeFromLiteral("1536", token.INT, 0)),
		"ETH_P_802_EX1":                     reflect.ValueOf(constant.MakeFromLiteral("34997", token.INT, 0)),
		"ETH_P_AARP":                        reflect.ValueOf(constant.MakeFromLiteral("33011", token.INT, 0)),
		"ETH_P_AF_IUCV":                     reflect.ValueOf(constant.MakeFromLiteral("64507", token.INT, 0)),
		"ETH_P_ALL":                         reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"ETH_P_AOE":                         reflect.ValueOf(constant.MakeFromLiteral("34978", token.INT, 0)),
		"ETH_P_ARCNET":                      reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"ETH_P_ARP":                         reflect.ValueOf(constant.MakeFromLiteral("2054", token.INT, 0)),
		"ETH_P_ATALK":                       reflect.ValueOf(constant.MakeFromLiteral("32923", token.INT, 0)),
		"ETH_P_ATMFATE":                     reflect.ValueOf(constant.MakeFromLiteral("34948", token.INT, 0)),
		"ETH_P_ATMMPOA":                     reflect.ValueOf(constant.MakeFromLiteral("34892", token.INT, 0)),
		"ETH_P_AX25":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"ETH_P_BATMAN":                      reflect.ValueOf(constant.MakeFromLiteral("17157", token.INT, 0)),
		"ETH_P_BPQ":                         reflect.ValueOf(constant.MakeFromLiteral("2303", token.INT, 0)),
		"ETH_P_CAIF":                        reflect.ValueOf(constant.MakeFromLiteral("247", token.INT, 0)),
		"ETH_P_CAN":                         reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"ETH_P_CANFD":                       reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"ETH_P_CFM":                         reflect.ValueOf(constant.MakeFromLiteral("35074", token.INT, 0)),
		"ETH_P_CONTROL":                     reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"ETH_P_CUST":                        reflect.ValueOf(constant.MakeFromLiteral("24582", token.INT, 0)),
		"ETH_P_DDCMP":                       reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"ETH_P_DEC":                         reflect.ValueOf(constant.MakeFromLiteral("24576", token.INT, 0)),
		"ETH_P_DIAG":                        reflect.ValueOf(constant.MakeFromLiteral("24581", token.INT, 0)),
		"ETH_P_DNA_DL":                      reflect.ValueOf(constant.MakeFromLiteral("24577", token.INT, 0)),
		"ETH_P_DNA_RC":                      reflect.ValueOf(constant.MakeFromLiteral("24578", token.INT, 0)),
		"ETH_P_DNA_RT":                      reflect.ValueOf(constant.MakeFromLiteral("24579", token.INT, 0)),
		"ETH_P_DSA":                         reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"ETH_P_DSA_8021Q":                   reflect.ValueOf(constant.MakeFromLiteral("56027", token.INT, 0)),
		"ETH_P_ECONET":                      reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"ETH_P_EDSA":                        reflect.ValueOf(constant.MakeFromLiteral("56026", token.INT, 0)),
		"ETH_P_ERSPAN":                      reflect.ValueOf(constant.MakeFromLiteral("35006", token.INT, 0)),
		"ETH_P_ERSPAN2":                     reflect.ValueOf(constant.MakeFromLiteral("8939", token.INT, 0)),
		"ETH_P_FCOE":                        reflect.ValueOf(constant.MakeFromLiteral("35078", token.INT, 0)),
		"ETH_P_FIP":                         reflect.ValueOf(constant.MakeFromLiteral("35092", token.INT, 0)),
		"ETH_P_HDLC":                        reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"ETH_P_HSR":                         reflect.ValueOf(constant.MakeFromLiteral("35119", token.INT, 0)),
		"ETH_P_IBOE":                        reflect.ValueOf(constant.MakeFromLiteral("35093", token.INT, 0)),
		"ETH_P_IEEE802154":                  reflect.ValueOf(constant.MakeFromLiteral("246", token.INT, 0)),
		"ETH_P_IEEEPUP":                     reflect.ValueOf(constant.MakeFromLiteral("2560", token.INT, 0)),
		"ETH_P_IEEEPUPAT":                   reflect.ValueOf(constant.MakeFromLiteral("2561", token.INT, 0)),
		"ETH_P_IFE":                         reflect.ValueOf(constant.MakeFromLiteral("60734", token.INT, 0)),
		"ETH_P_IP":                          reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"ETH_P_IPV6":                        reflect.ValueOf(constant.MakeFromLiteral("34525", token.INT, 0)),
		"ETH_P_IPX":                         reflect.ValueOf(constant.MakeFromLiteral("33079", token.INT, 0)),
		"ETH_P_IRDA":                        reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"ETH_P_LAT":                         reflect.ValueOf(constant.MakeFromLiteral("24580", token.INT, 0)),
		"ETH_P_LINK_CTL":                    reflect.ValueOf(constant.MakeFromLiteral("34924", token.INT, 0)),
		"ETH_P_LLDP":                        reflect.ValueOf(constant.MakeFromLiteral("35020", token.INT, 0)),
		"ETH_P_LOCALTALK":                   reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"ETH_P_LOOP":                        reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"ETH_P_LOOPBACK":                    reflect.ValueOf(constant.MakeFromLiteral("36864", token.INT, 0)),
		"ETH_P_MACSEC":                      reflect.ValueOf(constant.MakeFromLiteral("35045", token.INT, 0)),
		"ETH_P_MAP":                         reflect.ValueOf(constant.MakeFromLiteral("249", token.INT, 0)),
		"ETH_P_MCTP":                        reflect.ValueOf(constant.MakeFromLiteral("250", token.INT, 0)),
		"ETH_P_MOBITEX":                     reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"ETH_P_MPLS_MC":                     reflect.ValueOf(constant.MakeFromLiteral("34888", token.INT, 0)),
		"ETH_P_MPLS_UC":                     reflect.ValueOf(constant.MakeFromLiteral("34887", token.INT, 0)),
		"ETH_P_MRP":                         reflect.ValueOf(constant.MakeFromLiteral("35043", token.INT, 0)),
		"ETH_P_MVRP":                        reflect.ValueOf(constant.MakeFromLiteral("35061", token.INT, 0)),
		"ETH_P_NCSI":                        reflect.ValueOf(constant.MakeFromLiteral("35064", token.INT, 0)),
		"ETH_P_NSH":                         reflect.ValueOf(constant.MakeFromLiteral("35151", token.INT, 0)),
		"ETH_P_PAE":                         reflect.ValueOf(constant.MakeFromLiteral("34958", token.INT, 0)),
		"ETH_P_PAUSE":                       reflect.ValueOf(constant.MakeFromLiteral("34824", token.INT, 0)),
		"ETH_P_PHONET":                      reflect.ValueOf(constant.MakeFromLiteral("245", token.INT, 0)),
		"ETH_P_PPPTALK":                     reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"ETH_P_PPP_DISC":                    reflect.ValueOf(constant.MakeFromLiteral("34915", token.INT, 0)),
		"ETH_P_PPP_MP":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"ETH_P_PPP_SES":                     reflect.ValueOf(constant.MakeFromLiteral("34916", token.INT, 0)),
		"ETH_P_PREAUTH":                     reflect.ValueOf(constant.MakeFromLiteral("35015", token.INT, 0)),
		"ETH_P_PRP":                         reflect.ValueOf(constant.MakeFromLiteral("35067", token.INT, 0)),
		"ETH_P_PUP":                         reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"ETH_P_PUPAT":                       reflect.ValueOf(constant.MakeFromLiteral("513", token.INT, 0)),
		"ETH_P_QINQ1":                       reflect.ValueOf(constant.MakeFromLiteral("37120", token.INT, 0)),
		"ETH_P_QINQ2":                       reflect.ValueOf(constant.MakeFromLiteral("37376", token.INT, 0)),
		"ETH_P_QINQ3":                       reflect.ValueOf(constant.MakeFromLiteral("37632", token.INT, 0)),
		"ETH_P_RARP":                        reflect.ValueOf(constant.MakeFromLiteral("32821", token.INT, 0)),
		"ETH_P_REALTEK":                     reflect.ValueOf(constant.MakeFromLiteral("34969", token.INT, 0)),
		"ETH_P_SCA":                         reflect.ValueOf(constant.MakeFromLiteral("24583", token.INT, 0)),
		"ETH_P_SLOW":                        reflect.ValueOf(constant.MakeFromLiteral("34825", token.INT, 0)),
		"ETH_P_SNAP":                        reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"ETH_P_TDLS":                        reflect.ValueOf(constant.MakeFromLiteral("35085", token.INT, 0)),
		"ETH_P_TEB":                         reflect.ValueOf(constant.MakeFromLiteral("25944", token.INT, 0)),
		"ETH_P_TIPC":                        reflect.ValueOf(constant.MakeFromLiteral("35018", token.INT, 0)),
		"ETH_P_TRAILER":                     reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"ETH_P_TR_802_2":                    reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"ETH_P_TSN":                         reflect.ValueOf(constant.MakeFromLiteral("8944", token.INT, 0)),
		"ETH_P_WAN_PPP":                     reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"ETH_P_WCCP":                        reflect.ValueOf(constant.MakeFromLiteral("34878", token.INT, 0)),
		"ETH_P_X25":                         reflect.ValueOf(constant.MakeFromLiteral("2053", token.INT, 0)),
		"ETH_P_XDSA":                        reflect.ValueOf(constant.MakeFromLiteral("248", token.INT, 0)),
		"ETIME":                             reflect.ValueOf(syscall.ETIME),
		"ETIMEDOUT":                         reflect.ValueOf(syscall.ETIMEDOUT),
		"ETOOMANYREFS":                      reflect.ValueOf(syscall.ETOOMANYREFS),
		"ETXTBSY":                           reflect.ValueOf(syscall.ETXTBSY),
		"EUCLEAN":                           reflect.ValueOf(syscall.EUCLEAN),
		"EUNATCH":                           reflect.ValueOf(syscall.EUNATCH),
		"EUSERS":                            reflect.ValueOf(syscall.EUSERS),
		"EWOULDBLOCK":                       reflect.ValueOf(syscall.EWOULDBLOCK),
		"EXDEV":                             reflect.ValueOf(syscall.EXDEV),
		"EXFULL":                            reflect.ValueOf(syscall.EXFULL),
		"EXTA":                              reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"EXTB":                              reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"EXTPROC":                           reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"Environ":                           reflect.ValueOf(syscall.Environ),
		"EpollCreate":                       reflect.ValueOf(syscall.EpollCreate),
		"EpollCreate1":                      reflect.ValueOf(syscall.EpollCreate1),
		"EpollCtl":                          reflect.ValueOf(syscall.EpollCtl),
		"EpollWait":                         reflect.ValueOf(syscall.EpollWait),
		"FD_CLOEXEC":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"FD_SETSIZE":                        reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"FLUSHO":                            reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"F_ADD_SEALS":                       reflect.ValueOf(constant.MakeFromLiteral("1033", token.INT, 0)),
		"F_DUPFD":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"F_DUPFD_CLOEXEC":                   reflect.ValueOf(constant.MakeFromLiteral("1030", token.INT, 0)),
		"F_EXLCK":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"F_GETFD":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"F_GETFL":                           reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"F_GETLEASE":                        reflect.ValueOf(constant.MakeFromLiteral("1025", token.INT, 0)),
		"F_GETLK":                           reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"F_GETLK64":                         reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"F_GETOWN":                          reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"F_GETOWN_EX":                       reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"F_GETPIPE_SZ":                      reflect.ValueOf(constant.MakeFromLiteral("1032", token.INT, 0)),
		"F_GETSIG":                          reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"F_GET_FILE_RW_HINT":                reflect.ValueOf(constant.MakeFromLiteral("1037", token.INT, 0)),
		"F_GET_RW_HINT":                     reflect.ValueOf(constant.MakeFromLiteral("1035", token.INT, 0)),
		"F_GET_SEALS":                       reflect.ValueOf(constant.MakeFromLiteral("1034", token.INT, 0)),
		"F_LOCK":                            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"F_NOTIFY":                          reflect.ValueOf(constant.MakeFromLiteral("1026", token.INT, 0)),
		"F_OFD_GETLK":                       reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"F_OFD_SETLK":                       reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"F_OFD_SETLKW":                      reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"F_OK":                              reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"F_RDLCK":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"F_SEAL_FUTURE_WRITE":               reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"F_SEAL_GROW":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"F_SEAL_SEAL":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"F_SEAL_SHRINK":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"F_SEAL_WRITE":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"F_SETFD":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"F_SETFL":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"F_SETLEASE":                        reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"F_SETLK":                           reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"F_SETLK64":                         reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"F_SETLKW":                          reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"F_SETLKW64":                        reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"F_SETOWN":                          reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"F_SETOWN_EX":                       reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"F_SETPIPE_SZ":                      reflect.ValueOf(constant.MakeFromLiteral("1031", token.INT, 0)),
		"F_SETSIG":                          reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"F_SET_FILE_RW_HINT":                reflect.ValueOf(constant.MakeFromLiteral("1038", token.INT, 0)),
		"F_SET_RW_HINT":                     reflect.ValueOf(constant.MakeFromLiteral("1036", token.INT, 0)),
		"F_SHLCK":                           reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"F_TEST":                            reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"F_TLOCK":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"F_ULOCK":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"F_UNLCK":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"F_WRLCK":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"Faccessat":                         reflect.ValueOf(syscall.Faccessat),
		"Fallocate":                         reflect.ValueOf(syscall.Fallocate),
		"Fchdir":                            reflect.ValueOf(syscall.Fchdir),
		"Fchmod":                            reflect.ValueOf(syscall.Fchmod),
		"Fchmodat":                          reflect.ValueOf(syscall.Fchmodat),
		"Fchown":                            reflect.ValueOf(syscall.Fchown),
		"Fchownat":                          reflect.ValueOf(syscall.Fchownat),
		"FcntlFlock":                        reflect.ValueOf(syscall.FcntlFlock),
		"Fdatasync":                         reflect.ValueOf(syscall.Fdatasync),
		"Flock":                             reflect.ValueOf(syscall.Flock),
		"ForkLock":                          reflect.ValueOf(&syscall.ForkLock).Elem(),
		"Fstat":                             reflect.ValueOf(syscall.Fstat),
		"Fstatat":                           reflect.ValueOf(syscall.Fstatat),
		"Fstatfs":                           reflect.ValueOf(syscall.Fstatfs),
		"Fsync":                             reflect.ValueOf(syscall.Fsync),
		"Ftruncate":                         reflect.ValueOf(syscall.Ftruncate),
		"Futimes":                           reflect.ValueOf(syscall.Futimes),
		"Futimesat":                         reflect.ValueOf(syscall.Futimesat),
		"Getcwd":                            reflect.ValueOf(syscall.Getcwd),
		"Getdents":                          reflect.ValueOf(syscall.Getdents),
		"Getegid":                           reflect.ValueOf(syscall.Getegid),
		"Getenv":                            reflect.ValueOf(syscall.Getenv),
		"Geteuid":                           reflect.ValueOf(syscall.Geteuid),
		"Getgid":                            reflect.ValueOf(syscall.Getgid),
		"Getgroups":                         reflect.ValueOf(syscall.Getgroups),
		"Getpagesize":                       reflect.ValueOf(syscall.Getpagesize),
		"Getpeername":                       reflect.ValueOf(syscall.Getpeername),
		"Getpgid":                           reflect.ValueOf(syscall.Getpgid),
		"Getpgrp":                           reflect.ValueOf(syscall.Getpgrp),
		"Getpid":                            reflect.ValueOf(syscall.Getpid),
		"Getppid":                           reflect.ValueOf(syscall.Getppid),
		"Getpriority":                       reflect.ValueOf(syscall.Getpriority),
		"Getrlimit":                         reflect.ValueOf(syscall.Getrlimit),
		"Getrusage":                         reflect.ValueOf(syscall.Getrusage),
		"Getsockname":                       reflect.ValueOf(syscall.Getsockname),
		"GetsockoptICMPv6Filter":            reflect.ValueOf(syscall.GetsockoptICMPv6Filter),
		"GetsockoptIPMreq":                  reflect.ValueOf(syscall.GetsockoptIPMreq),
		"GetsockoptIPMreqn":                 reflect.ValueOf(syscall.GetsockoptIPMreqn),
		"GetsockoptIPv6MTUInfo":             reflect.ValueOf(syscall.GetsockoptIPv6MTUInfo),
		"GetsockoptIPv6Mreq":                reflect.ValueOf(syscall.GetsockoptIPv6Mreq),
		"GetsockoptInet4Addr":               reflect.ValueOf(syscall.GetsockoptInet4Addr),
		"GetsockoptInt":                     reflect.ValueOf(syscall.GetsockoptInt),
		"GetsockoptUcred":                   reflect.ValueOf(syscall.GetsockoptUcred),
		"Gettid":                            reflect.ValueOf(syscall.Gettid),
		"Gettimeofday":                      reflect.ValueOf(syscall.Gettimeofday),
		"Getuid":                            reflect.ValueOf(syscall.Getuid),
		"Getwd":                             reflect.ValueOf(syscall.Getwd),
		"Getxattr":                          reflect.ValueOf(syscall.Getxattr),
		"HUPCL":                             reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"ICANON":                            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"ICMPV6_FILTER":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"ICRNL":                             reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"IEXTEN":                            reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"IFA_ADDRESS":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFA_ANYCAST":                       reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"IFA_BROADCAST":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IFA_CACHEINFO":                     reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IFA_F_DADFAILED":                   reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IFA_F_DEPRECATED":                  reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IFA_F_HOMEADDRESS":                 reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IFA_F_MANAGETEMPADDR":              reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"IFA_F_MCAUTOJOIN":                  reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"IFA_F_NODAD":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IFA_F_NOPREFIXROUTE":               reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"IFA_F_OPTIMISTIC":                  reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IFA_F_PERMANENT":                   reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IFA_F_SECONDARY":                   reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFA_F_STABLE_PRIVACY":              reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"IFA_F_TEMPORARY":                   reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFA_F_TENTATIVE":                   reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"IFA_LABEL":                         reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IFA_LOCAL":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IFA_MAX":                           reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IFA_MULTICAST":                     reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"IFA_UNSPEC":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IFF_ALLMULTI":                      reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"IFF_ATTACH_QUEUE":                  reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"IFF_AUTOMEDIA":                     reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"IFF_BROADCAST":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IFF_DEBUG":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IFF_DETACH_QUEUE":                  reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"IFF_DORMANT":                       reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"IFF_DYNAMIC":                       reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"IFF_ECHO":                          reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"IFF_LOOPBACK":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IFF_LOWER_UP":                      reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"IFF_MASTER":                        reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"IFF_MULTICAST":                     reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"IFF_MULTI_QUEUE":                   reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"IFF_NAPI":                          reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IFF_NAPI_FRAGS":                    reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IFF_NOARP":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IFF_NOFILTER":                      reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"IFF_NOTRAILERS":                    reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IFF_NO_PI":                         reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"IFF_ONE_QUEUE":                     reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"IFF_PERSIST":                       reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"IFF_POINTOPOINT":                   reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IFF_PORTSEL":                       reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"IFF_PROMISC":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"IFF_RUNNING":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"IFF_SLAVE":                         reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"IFF_TAP":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IFF_TUN":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFF_TUN_EXCL":                      reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"IFF_UP":                            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFF_VNET_HDR":                      reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"IFF_VOLATILE":                      reflect.ValueOf(constant.MakeFromLiteral("461914", token.INT, 0)),
		"IFLA_ADDRESS":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFLA_BROADCAST":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IFLA_COST":                         reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IFLA_IFALIAS":                      reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"IFLA_IFNAME":                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IFLA_LINK":                         reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"IFLA_LINKINFO":                     reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"IFLA_LINKMODE":                     reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"IFLA_MAP":                          reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"IFLA_MASTER":                       reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IFLA_MAX":                          reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"IFLA_MTU":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IFLA_NET_NS_PID":                   reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"IFLA_OPERSTATE":                    reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IFLA_PRIORITY":                     reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IFLA_PROTINFO":                     reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IFLA_QDISC":                        reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IFLA_STATS":                        reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"IFLA_TXQLEN":                       reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"IFLA_UNSPEC":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IFLA_WEIGHT":                       reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"IFLA_WIRELESS":                     reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"IFNAMSIZ":                          reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IGNBRK":                            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IGNCR":                             reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IGNPAR":                            reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IMAXBEL":                           reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"INLCR":                             reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"INPCK":                             reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IN_ACCESS":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IN_ALL_EVENTS":                     reflect.ValueOf(constant.MakeFromLiteral("4095", token.INT, 0)),
		"IN_ATTRIB":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IN_CLASSA_HOST":                    reflect.ValueOf(constant.MakeFromLiteral("16777215", token.INT, 0)),
		"IN_CLASSA_MAX":                     reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IN_CLASSA_NET":                     reflect.ValueOf(constant.MakeFromLiteral("4278190080", token.INT, 0)),
		"IN_CLASSA_NSHIFT":                  reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"IN_CLASSB_HOST":                    reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"IN_CLASSB_MAX":                     reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"IN_CLASSB_NET":                     reflect.ValueOf(constant.MakeFromLiteral("4294901760", token.INT, 0)),
		"IN_CLASSB_NSHIFT":                  reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IN_CLASSC_HOST":                    reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"IN_CLASSC_NET":                     reflect.ValueOf(constant.MakeFromLiteral("4294967040", token.INT, 0)),
		"IN_CLASSC_NSHIFT":                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IN_CLOEXEC":                        reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"IN_CLOSE":                          reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"IN_CLOSE_NOWRITE":                  reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IN_CLOSE_WRITE":                    reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IN_CREATE":                         reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"IN_DELETE":                         reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"IN_DELETE_SELF":                    reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"IN_DONT_FOLLOW":                    reflect.ValueOf(constant.MakeFromLiteral("33554432", token.INT, 0)),
		"IN_EXCL_UNLINK":                    reflect.ValueOf(constant.MakeFromLiteral("67108864", token.INT, 0)),
		"IN_IGNORED":                        reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"IN_ISDIR":                          reflect.ValueOf(constant.MakeFromLiteral("1073741824", token.INT, 0)),
		"IN_LOOPBACKNET":                    reflect.ValueOf(constant.MakeFromLiteral("127", token.INT, 0)),
		"IN_MASK_ADD":                       reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"IN_MASK_CREATE":                    reflect.ValueOf(constant.MakeFromLiteral("268435456", token.INT, 0)),
		"IN_MODIFY":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IN_MOVE":                           reflect.ValueOf(constant.MakeFromLiteral("192", token.INT, 0)),
		"IN_MOVED_FROM":                     reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"IN_MOVED_TO":                       reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IN_MOVE_SELF":                      reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"IN_NONBLOCK":                       reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"IN_ONESHOT":                        reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"IN_ONLYDIR":                        reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"IN_OPEN":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IN_Q_OVERFLOW":                     reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"IN_UNMOUNT":                        reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"IPPROTO_AH":                        reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"IPPROTO_BEETPH":                    reflect.ValueOf(constant.MakeFromLiteral("94", token.INT, 0)),
		"IPPROTO_COMP":                      reflect.ValueOf(constant.MakeFromLiteral("108", token.INT, 0)),
		"IPPROTO_DCCP":                      reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"IPPROTO_DSTOPTS":                   reflect.ValueOf(constant.MakeFromLiteral("60", token.INT, 0)),
		"IPPROTO_EGP":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IPPROTO_ENCAP":                     reflect.ValueOf(constant.MakeFromLiteral("98", token.INT, 0)),
		"IPPROTO_ESP":                       reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"IPPROTO_ETHERNET":                  reflect.ValueOf(constant.MakeFromLiteral("143", token.INT, 0)),
		"IPPROTO_FRAGMENT":                  reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"IPPROTO_GRE":                       reflect.ValueOf(constant.MakeFromLiteral("47", token.INT, 0)),
		"IPPROTO_HOPOPTS":                   reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPPROTO_ICMP":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPPROTO_ICMPV6":                    reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"IPPROTO_IDP":                       reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"IPPROTO_IGMP":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IPPROTO_IP":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPPROTO_IPIP":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IPPROTO_IPV6":                      reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"IPPROTO_MH":                        reflect.ValueOf(constant.MakeFromLiteral("135", token.INT, 0)),
		"IPPROTO_MPLS":                      reflect.ValueOf(constant.MakeFromLiteral("137", token.INT, 0)),
		"IPPROTO_MPTCP":                     reflect.ValueOf(constant.MakeFromLiteral("262", token.INT, 0)),
		"IPPROTO_MTP":                       reflect.ValueOf(constant.MakeFromLiteral("92", token.INT, 0)),
		"IPPROTO_NONE":                      reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"IPPROTO_PIM":                       reflect.ValueOf(constant.MakeFromLiteral("103", token.INT, 0)),
		"IPPROTO_PUP":                       reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IPPROTO_RAW":                       reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"IPPROTO_ROUTING":                   reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"IPPROTO_RSVP":                      reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"IPPROTO_SCTP":                      reflect.ValueOf(constant.MakeFromLiteral("132", token.INT, 0)),
		"IPPROTO_TCP":                       reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IPPROTO_TP":                        reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"IPPROTO_UDP":                       reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"IPPROTO_UDPLITE":                   reflect.ValueOf(constant.MakeFromLiteral("136", token.INT, 0)),
		"IPV6_2292DSTOPTS":                  reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IPV6_2292HOPLIMIT":                 reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IPV6_2292HOPOPTS":                  reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IPV6_2292PKTINFO":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IPV6_2292PKTOPTIONS":               reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IPV6_2292RTHDR":                    reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"IPV6_ADDRFORM":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPV6_ADDR_PREFERENCES":             reflect.ValueOf(constant.MakeFromLiteral("72", token.INT, 0)),
		"IPV6_ADD_MEMBERSHIP":               reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"IPV6_AUTHHDR":                      reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IPV6_AUTOFLOWLABEL":                reflect.ValueOf(constant.MakeFromLiteral("70", token.INT, 0)),
		"IPV6_CHECKSUM":                     reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"IPV6_DONTFRAG":                     reflect.ValueOf(constant.MakeFromLiteral("62", token.INT, 0)),
		"IPV6_DROP_MEMBERSHIP":              reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"IPV6_DSTOPTS":                      reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"IPV6_FREEBIND":                     reflect.ValueOf(constant.MakeFromLiteral("78", token.INT, 0)),
		"IPV6_HDRINCL":                      reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"IPV6_HOPLIMIT":                     reflect.ValueOf(constant.MakeFromLiteral("52", token.INT, 0)),
		"IPV6_HOPOPTS":                      reflect.ValueOf(constant.MakeFromLiteral("54", token.INT, 0)),
		"IPV6_IPSEC_POLICY":                 reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"IPV6_JOIN_ANYCAST":                 reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"IPV6_JOIN_GROUP":                   reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"IPV6_LEAVE_ANYCAST":                reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"IPV6_LEAVE_GROUP":                  reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"IPV6_MINHOPCOUNT":                  reflect.ValueOf(constant.MakeFromLiteral("73", token.INT, 0)),
		"IPV6_MTU":                          reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"IPV6_MTU_DISCOVER":                 reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"IPV6_MULTICAST_ALL":                reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"IPV6_MULTICAST_HOPS":               reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"IPV6_MULTICAST_IF":                 reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"IPV6_MULTICAST_LOOP":               reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"IPV6_NEXTHOP":                      reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IPV6_ORIGDSTADDR":                  reflect.ValueOf(constant.MakeFromLiteral("74", token.INT, 0)),
		"IPV6_PATHMTU":                      reflect.ValueOf(constant.MakeFromLiteral("61", token.INT, 0)),
		"IPV6_PKTINFO":                      reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"IPV6_PMTUDISC_DO":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IPV6_PMTUDISC_DONT":                reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPV6_PMTUDISC_INTERFACE":           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IPV6_PMTUDISC_OMIT":                reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"IPV6_PMTUDISC_PROBE":               reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IPV6_PMTUDISC_WANT":                reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPV6_RECVDSTOPTS":                  reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"IPV6_RECVERR":                      reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"IPV6_RECVERR_RFC4884":              reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"IPV6_RECVFRAGSIZE":                 reflect.ValueOf(constant.MakeFromLiteral("77", token.INT, 0)),
		"IPV6_RECVHOPLIMIT":                 reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"IPV6_RECVHOPOPTS":                  reflect.ValueOf(constant.MakeFromLiteral("53", token.INT, 0)),
		"IPV6_RECVORIGDSTADDR":              reflect.ValueOf(constant.MakeFromLiteral("74", token.INT, 0)),
		"IPV6_RECVPATHMTU":                  reflect.ValueOf(constant.MakeFromLiteral("60", token.INT, 0)),
		"IPV6_RECVPKTINFO":                  reflect.ValueOf(constant.MakeFromLiteral("49", token.INT, 0)),
		"IPV6_RECVRTHDR":                    reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"IPV6_RECVTCLASS":                   reflect.ValueOf(constant.MakeFromLiteral("66", token.INT, 0)),
		"IPV6_ROUTER_ALERT":                 reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"IPV6_ROUTER_ALERT_ISOLATE":         reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"IPV6_RTHDR":                        reflect.ValueOf(constant.MakeFromLiteral("57", token.INT, 0)),
		"IPV6_RTHDRDSTOPTS":                 reflect.ValueOf(constant.MakeFromLiteral("55", token.INT, 0)),
		"IPV6_RTHDR_LOOSE":                  reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPV6_RTHDR_STRICT":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPV6_RTHDR_TYPE_0":                 reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPV6_RXDSTOPTS":                    reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"IPV6_RXHOPOPTS":                    reflect.ValueOf(constant.MakeFromLiteral("54", token.INT, 0)),
		"IPV6_TCLASS":                       reflect.ValueOf(constant.MakeFromLiteral("67", token.INT, 0)),
		"IPV6_TRANSPARENT":                  reflect.ValueOf(constant.MakeFromLiteral("75", token.INT, 0)),
		"IPV6_UNICAST_HOPS":                 reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IPV6_UNICAST_IF":                   reflect.ValueOf(constant.MakeFromLiteral("76", token.INT, 0)),
		"IPV6_V6ONLY":                       reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"IPV6_XFRM_POLICY":                  reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"IP_ADD_MEMBERSHIP":                 reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"IP_ADD_SOURCE_MEMBERSHIP":          reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"IP_BIND_ADDRESS_NO_PORT":           reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"IP_BLOCK_SOURCE":                   reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"IP_CHECKSUM":                       reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"IP_DEFAULT_MULTICAST_LOOP":         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IP_DEFAULT_MULTICAST_TTL":          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IP_DF":                             reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"IP_DROP_MEMBERSHIP":                reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"IP_DROP_SOURCE_MEMBERSHIP":         reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"IP_FREEBIND":                       reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"IP_HDRINCL":                        reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IP_IPSEC_POLICY":                   reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IP_MAXPACKET":                      reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"IP_MAX_MEMBERSHIPS":                reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"IP_MF":                             reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"IP_MINTTL":                         reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"IP_MSFILTER":                       reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"IP_MSS":                            reflect.ValueOf(constant.MakeFromLiteral("576", token.INT, 0)),
		"IP_MTU":                            reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"IP_MTU_DISCOVER":                   reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IP_MULTICAST_ALL":                  reflect.ValueOf(constant.MakeFromLiteral("49", token.INT, 0)),
		"IP_MULTICAST_IF":                   reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IP_MULTICAST_LOOP":                 reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"IP_MULTICAST_TTL":                  reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"IP_NODEFRAG":                       reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"IP_OFFMASK":                        reflect.ValueOf(constant.MakeFromLiteral("8191", token.INT, 0)),
		"IP_OPTIONS":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IP_ORIGDSTADDR":                    reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"IP_PASSSEC":                        reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"IP_PKTINFO":                        reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IP_PKTOPTIONS":                     reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IP_PMTUDISC":                       reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IP_PMTUDISC_DO":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IP_PMTUDISC_DONT":                  reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IP_PMTUDISC_INTERFACE":             reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IP_PMTUDISC_OMIT":                  reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"IP_PMTUDISC_PROBE":                 reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IP_PMTUDISC_WANT":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IP_RECVERR":                        reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"IP_RECVERR_RFC4884":                reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"IP_RECVFRAGSIZE":                   reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"IP_RECVOPTS":                       reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IP_RECVORIGDSTADDR":                reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"IP_RECVRETOPTS":                    reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"IP_RECVTOS":                        reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"IP_RECVTTL":                        reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IP_RETOPTS":                        reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"IP_RF":                             reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"IP_ROUTER_ALERT":                   reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"IP_TOS":                            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IP_TRANSPARENT":                    reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"IP_TTL":                            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IP_UNBLOCK_SOURCE":                 reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"IP_UNICAST_IF":                     reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"IP_XFRM_POLICY":                    reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"ISIG":                              reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"ISTRIP":                            reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IUCLC":                             reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"IUTF8":                             reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"IXANY":                             reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"IXOFF":                             reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"IXON":                              reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"ImplementsGetwd":                   reflect.ValueOf(syscall.ImplementsGetwd),
		"InotifyAddWatch":                   reflect.ValueOf(syscall.InotifyAddWatch),
		"InotifyInit":                       reflect.ValueOf(syscall.InotifyInit),
		"InotifyInit1":                      reflect.ValueOf(syscall.InotifyInit1),
		"InotifyRmWatch":                    reflect.ValueOf(syscall.InotifyRmWatch),
		"Klogctl":                           reflect.ValueOf(syscall.Klogctl),
		"LINUX_REBOOT_CMD_CAD_OFF":          reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"LINUX_REBOOT_CMD_CAD_ON":           reflect.ValueOf(constant.MakeFromLiteral("2309737967", token.INT, 0)),
		"LINUX_REBOOT_CMD_HALT":             reflect.ValueOf(constant.MakeFromLiteral("3454992675", token.INT, 0)),
		"LINUX_REBOOT_CMD_KEXEC":            reflect.ValueOf(constant.MakeFromLiteral("1163412803", token.INT, 0)),
		"LINUX_REBOOT_CMD_POWER_OFF":        reflect.ValueOf(constant.MakeFromLiteral("1126301404", token.INT, 0)),
		"LINUX_REBOOT_CMD_RESTART":          reflect.ValueOf(constant.MakeFromLiteral("19088743", token.INT, 0)),
		"LINUX_REBOOT_CMD_RESTART2":         reflect.ValueOf(constant.MakeFromLiteral("2712847316", token.INT, 0)),
		"LINUX_REBOOT_CMD_SW_SUSPEND":       reflect.ValueOf(constant.MakeFromLiteral("3489725666", token.INT, 0)),
		"LINUX_REBOOT_MAGIC1":               reflect.ValueOf(constant.MakeFromLiteral("4276215469", token.INT, 0)),
		"LINUX_REBOOT_MAGIC2":               reflect.ValueOf(constant.MakeFromLiteral("672274793", token.INT, 0)),
		"LOCK_EX":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"LOCK_NB":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"LOCK_SH":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"LOCK_UN":                           reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"Lchown":                            reflect.ValueOf(syscall.Lchown),
		"Link":                              reflect.ValueOf(syscall.Link),
		"Listen":                            reflect.ValueOf(syscall.Listen),
		"Listxattr":                         reflect.ValueOf(syscall.Listxattr),
		"LsfJump":                           reflect.ValueOf(syscall.LsfJump),
		"LsfSocket":                         reflect.ValueOf(syscall.LsfSocket),
		"LsfStmt":                           reflect.ValueOf(syscall.LsfStmt),
		"Lstat":                             reflect.ValueOf(syscall.Lstat),
		"MADV_COLD":                         reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"MADV_DODUMP":                       reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"MADV_DOFORK":                       reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"MADV_DONTDUMP":                     reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"MADV_DONTFORK":                     reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"MADV_DONTNEED":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"MADV_FREE":                         reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"MADV_HUGEPAGE":                     reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"MADV_HWPOISON":                     reflect.ValueOf(constant.MakeFromLiteral("100", token.INT, 0)),
		"MADV_KEEPONFORK":                   reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"MADV_MERGEABLE":                    reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"MADV_NOHUGEPAGE":                   reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"MADV_NORMAL":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MADV_PAGEOUT":                      reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"MADV_POPULATE_READ":                reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"MADV_POPULATE_WRITE":               reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"MADV_RANDOM":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MADV_REMOVE":                       reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"MADV_SEQUENTIAL":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MADV_UNMERGEABLE":                  reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"MADV_WILLNEED":                     reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"MADV_WIPEONFORK":                   reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"MAP_ANON":                          reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"MAP_ANONYMOUS":                     reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"MAP_DENYWRITE":                     reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"MAP_EXECUTABLE":                    reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"MAP_FILE":                          reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MAP_FIXED":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"MAP_FIXED_NOREPLACE":               reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"MAP_GROWSDOWN":                     reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"MAP_HUGETLB":                       reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"MAP_HUGE_MASK":                     reflect.ValueOf(constant.MakeFromLiteral("63", token.INT, 0)),
		"MAP_HUGE_SHIFT":                    reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"MAP_LOCKED":                        reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"MAP_NONBLOCK":                      reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"MAP_NORESERVE":                     reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"MAP_POPULATE":                      reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"MAP_PRIVATE":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MAP_SHARED":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MAP_SHARED_VALIDATE":               reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"MAP_STACK":                         reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"MAP_SYNC":                          reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"MAP_TYPE":                          reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"MCL_CURRENT":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MCL_FUTURE":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MCL_ONFAULT":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"MNT_DETACH":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MNT_EXPIRE":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"MNT_FORCE":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MSG_BATCH":                         reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"MSG_CMSG_CLOEXEC":                  reflect.ValueOf(constant.MakeFromLiteral("1073741824", token.INT, 0)),
		"MSG_CONFIRM":                       reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"MSG_CTRUNC":                        reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"MSG_DONTROUTE":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"MSG_DONTWAIT":                      reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"MSG_EOR":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"MSG_ERRQUEUE":                      reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"MSG_FASTOPEN":                      reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"MSG_FIN":                           reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"MSG_MORE":                          reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"MSG_NOSIGNAL":                      reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"MSG_OOB":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MSG_PEEK":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MSG_PROXY":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"MSG_RST":                           reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"MSG_SYN":                           reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"MSG_TRUNC":                         reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"MSG_TRYHARD":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"MSG_WAITALL":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"MSG_WAITFORONE":                    reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"MSG_ZEROCOPY":                      reflect.ValueOf(constant.MakeFromLiteral("67108864", token.INT, 0)),
		"MS_ACTIVE":                         reflect.ValueOf(constant.MakeFromLiteral("1073741824", token.INT, 0)),
		"MS_ASYNC":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MS_BIND":                           reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"MS_DIRSYNC":                        reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"MS_INVALIDATE":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MS_I_VERSION":                      reflect.ValueOf(constant.MakeFromLiteral("8388608", token.INT, 0)),
		"MS_KERNMOUNT":                      reflect.ValueOf(constant.MakeFromLiteral("4194304", token.INT, 0)),
		"MS_LAZYTIME":                       reflect.ValueOf(constant.MakeFromLiteral("33554432", token.INT, 0)),
		"MS_MANDLOCK":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"MS_MGC_MSK":                        reflect.ValueOf(constant.MakeFromLiteral("4294901760", token.INT, 0)),
		"MS_MGC_VAL":                        reflect.ValueOf(constant.MakeFromLiteral("3236757504", token.INT, 0)),
		"MS_MOVE":                           reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"MS_NOATIME":                        reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"MS_NODEV":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"MS_NODIRATIME":                     reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"MS_NOEXEC":                         reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"MS_NOSUID":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MS_NOSYMFOLLOW":                    reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"MS_NOUSER":                         reflect.ValueOf(constant.MakeFromLiteral("-2147483648", token.INT, 0)),
		"MS_POSIXACL":                       reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"MS_PRIVATE":                        reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"MS_RDONLY":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MS_REC":                            reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"MS_RELATIME":                       reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"MS_REMOUNT":                        reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"MS_RMT_MASK":                       reflect.ValueOf(constant.MakeFromLiteral("41943121", token.INT, 0)),
		"MS_SHARED":                         reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"MS_SILENT":                         reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"MS_SLAVE":                          reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"MS_STRICTATIME":                    reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"MS_SYNC":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"MS_SYNCHRONOUS":                    reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"MS_UNBINDABLE":                     reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"Madvise":                           reflect.ValueOf(syscall.Madvise),
		"Mkdir":                             reflect.ValueOf(syscall.Mkdir),
		"Mkdirat":                           reflect.ValueOf(syscall.Mkdirat),
		"Mkfifo":                            reflect.ValueOf(syscall.Mkfifo),
		"Mknod":                             reflect.ValueOf(syscall.Mknod),
		"Mknodat":                           reflect.ValueOf(syscall.Mknodat),
		"Mlock":                             reflect.ValueOf(syscall.Mlock),
		"Mlockall":                          reflect.ValueOf(syscall.Mlockall),
		"Mmap":                              reflect.ValueOf(syscall.Mmap),
		"Mount":                             reflect.ValueOf(syscall.Mount),
		"Mprotect":                          reflect.ValueOf(syscall.Mprotect),
		"Munlock":                           reflect.ValueOf(syscall.Munlock),
		"Munlockall":                        reflect.ValueOf(syscall.Munlockall),
		"Munmap":                            reflect.ValueOf(syscall.Munmap),
		"NAME_MAX":                          reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"NETLINK_ADD_MEMBERSHIP":            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"NETLINK_AUDIT":                     reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"NETLINK_BROADCAST_ERROR":           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"NETLINK_CAP_ACK":                   reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"NETLINK_CONNECTOR":                 reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"NETLINK_CRYPTO":                    reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"NETLINK_DNRTMSG":                   reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"NETLINK_DROP_MEMBERSHIP":           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"NETLINK_ECRYPTFS":                  reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"NETLINK_EXT_ACK":                   reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"NETLINK_FIB_LOOKUP":                reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"NETLINK_FIREWALL":                  reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"NETLINK_GENERIC":                   reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"NETLINK_GET_STRICT_CHK":            reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"NETLINK_INET_DIAG":                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"NETLINK_IP6_FW":                    reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"NETLINK_ISCSI":                     reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"NETLINK_KOBJECT_UEVENT":            reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"NETLINK_LISTEN_ALL_NSID":           reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"NETLINK_LIST_MEMBERSHIPS":          reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"NETLINK_NETFILTER":                 reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"NETLINK_NFLOG":                     reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"NETLINK_NO_ENOBUFS":                reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"NETLINK_PKTINFO":                   reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"NETLINK_RDMA":                      reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"NETLINK_ROUTE":                     reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"NETLINK_RX_RING":                   reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"NETLINK_SCSITRANSPORT":             reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"NETLINK_SELINUX":                   reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"NETLINK_SMC":                       reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"NETLINK_SOCK_DIAG":                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"NETLINK_TX_RING":                   reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"NETLINK_UNUSED":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"NETLINK_USERSOCK":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"NETLINK_XFRM":                      reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"NLA_ALIGNTO":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"NLA_F_NESTED":                      reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"NLA_F_NET_BYTEORDER":               reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"NLA_HDRLEN":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"NLMSG_ALIGNTO":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"NLMSG_DONE":                        reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"NLMSG_ERROR":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"NLMSG_HDRLEN":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"NLMSG_MIN_TYPE":                    reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"NLMSG_NOOP":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"NLMSG_OVERRUN":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"NLM_F_ACK":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"NLM_F_ACK_TLVS":                    reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"NLM_F_APPEND":                      reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"NLM_F_ATOMIC":                      reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"NLM_F_CAPPED":                      reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"NLM_F_CREATE":                      reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"NLM_F_DUMP":                        reflect.ValueOf(constant.MakeFromLiteral("768", token.INT, 0)),
		"NLM_F_DUMP_FILTERED":               reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"NLM_F_DUMP_INTR":                   reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"NLM_F_ECHO":                        reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"NLM_F_EXCL":                        reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"NLM_F_MATCH":                       reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"NLM_F_MULTI":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"NLM_F_NONREC":                      reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"NLM_F_REPLACE":                     reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"NLM_F_REQUEST":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"NLM_F_ROOT":                        reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"NOFLSH":                            reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"Nanosleep":                         reflect.ValueOf(syscall.Nanosleep),
		"NetlinkRIB":                        reflect.ValueOf(syscall.NetlinkRIB),
		"NsecToTimespec":                    reflect.ValueOf(syscall.NsecToTimespec),
		"NsecToTimeval":                     reflect.ValueOf(syscall.NsecToTimeval),
		"OCRNL":                             reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"OFDEL":                             reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"OFILL":                             reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"OLCUC":                             reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"ONLCR":                             reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"ONLRET":                            reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"ONOCR":                             reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"OPOST":                             reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"O_ACCMODE":                         reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"O_APPEND":                          reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"O_ASYNC":                           reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"O_CLOEXEC":                         reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"O_CREAT":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"O_DIRECT":                          reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"O_DIRECTORY":                       reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"O_DSYNC":                           reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"O_EXCL":                            reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"O_FSYNC":                           reflect.ValueOf(constant.MakeFromLiteral("1052672", token.INT, 0)),
		"O_LARGEFILE":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"O_NDELAY":                          reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"O_NOATIME":                         reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"O_NOCTTY":                          reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"O_NOFOLLOW":                        reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"O_NONBLOCK":                        reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"O_PATH":                            reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"O_RDONLY":                          reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"O_RDWR":                            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"O_RSYNC":                           reflect.ValueOf(constant.MakeFromLiteral("1052672", token.INT, 0)),
		"O_SYNC":                            reflect.ValueOf(constant.MakeFromLiteral("1052672", token.INT, 0)),
		"O_TMPFILE":                         reflect.ValueOf(constant.MakeFromLiteral("4259840", token.INT, 0)),
		"O_TRUNC":                           reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"O_WRONLY":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"Open":                              reflect.ValueOf(syscall.Open),
		"Openat":                            reflect.ValueOf(syscall.Openat),
		"PACKET_ADD_MEMBERSHIP":             reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PACKET_AUXDATA":                    reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PACKET_BROADCAST":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PACKET_COPY_THRESH":                reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"PACKET_DROP_MEMBERSHIP":            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PACKET_FANOUT":                     reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"PACKET_FANOUT_CBPF":                reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"PACKET_FANOUT_CPU":                 reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PACKET_FANOUT_DATA":                reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"PACKET_FANOUT_EBPF":                reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"PACKET_FANOUT_FLAG_DEFRAG":         reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"PACKET_FANOUT_FLAG_ROLLOVER":       reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"PACKET_FANOUT_FLAG_UNIQUEID":       reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"PACKET_FANOUT_HASH":                reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PACKET_FANOUT_LB":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PACKET_FANOUT_QM":                  reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"PACKET_FANOUT_RND":                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PACKET_FANOUT_ROLLOVER":            reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"PACKET_FASTROUTE":                  reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"PACKET_HDRLEN":                     reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"PACKET_HOST":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PACKET_IGNORE_OUTGOING":            reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"PACKET_KERNEL":                     reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"PACKET_LOOPBACK":                   reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"PACKET_LOSS":                       reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"PACKET_MR_ALLMULTI":                reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PACKET_MR_MULTICAST":               reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PACKET_MR_PROMISC":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PACKET_MR_UNICAST":                 reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"PACKET_MULTICAST":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PACKET_ORIGDEV":                    reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"PACKET_OTHERHOST":                  reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"PACKET_OUTGOING":                   reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PACKET_QDISC_BYPASS":               reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"PACKET_RECV_OUTPUT":                reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"PACKET_RESERVE":                    reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"PACKET_ROLLOVER_STATS":             reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"PACKET_RX_RING":                    reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"PACKET_STATISTICS":                 reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"PACKET_TIMESTAMP":                  reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"PACKET_TX_HAS_OFF":                 reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"PACKET_TX_RING":                    reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"PACKET_TX_TIMESTAMP":               reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"PACKET_USER":                       reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"PACKET_VERSION":                    reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"PACKET_VNET_HDR":                   reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"PARENB":                            reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"PARITY_CRC16_PR0":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PARITY_CRC16_PR0_CCITT":            reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PARITY_CRC16_PR1":                  reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"PARITY_CRC16_PR1_CCITT":            reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"PARITY_CRC32_PR0_CCITT":            reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"PARITY_CRC32_PR1_CCITT":            reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"PARITY_DEFAULT":                    reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PARITY_NONE":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PARMRK":                            reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PARODD":                            reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"PENDIN":                            reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"PRIO_PGRP":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PRIO_PROCESS":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PRIO_USER":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PROT_EXEC":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PROT_GROWSDOWN":                    reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"PROT_GROWSUP":                      reflect.ValueOf(constant.MakeFromLiteral("33554432", token.INT, 0)),
		"PROT_NONE":                         reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PROT_READ":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PROT_WRITE":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_CAPBSET_DROP":                   reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"PR_CAPBSET_READ":                   reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"PR_CAP_AMBIENT":                    reflect.ValueOf(constant.MakeFromLiteral("47", token.INT, 0)),
		"PR_CAP_AMBIENT_CLEAR_ALL":          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PR_CAP_AMBIENT_IS_SET":             reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_CAP_AMBIENT_LOWER":              reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"PR_CAP_AMBIENT_RAISE":              reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_ENDIAN_BIG":                     reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PR_ENDIAN_LITTLE":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_ENDIAN_PPC_LITTLE":              reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_FPEMU_NOPRINT":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_FPEMU_SIGFPE":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_FP_EXC_ASYNC":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_FP_EXC_DISABLED":                reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PR_FP_EXC_DIV":                     reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"PR_FP_EXC_INV":                     reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"PR_FP_EXC_NONRECOV":                reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_FP_EXC_OVF":                     reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"PR_FP_EXC_PRECISE":                 reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"PR_FP_EXC_RES":                     reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"PR_FP_EXC_SW_ENABLE":               reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"PR_FP_EXC_UND":                     reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"PR_FP_MODE_FR":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_FP_MODE_FRE":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_GET_CHILD_SUBREAPER":            reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"PR_GET_DUMPABLE":                   reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"PR_GET_ENDIAN":                     reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"PR_GET_FPEMU":                      reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"PR_GET_FPEXC":                      reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"PR_GET_FP_MODE":                    reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"PR_GET_IO_FLUSHER":                 reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"PR_GET_KEEPCAPS":                   reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"PR_GET_NAME":                       reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"PR_GET_NO_NEW_PRIVS":               reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"PR_GET_PDEATHSIG":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_GET_SECCOMP":                    reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"PR_GET_SECUREBITS":                 reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"PR_GET_SPECULATION_CTRL":           reflect.ValueOf(constant.MakeFromLiteral("52", token.INT, 0)),
		"PR_GET_TAGGED_ADDR_CTRL":           reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"PR_GET_THP_DISABLE":                reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"PR_GET_TID_ADDRESS":                reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"PR_GET_TIMERSLACK":                 reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"PR_GET_TIMING":                     reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"PR_GET_TSC":                        reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"PR_GET_UNALIGN":                    reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"PR_MCE_KILL":                       reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"PR_MCE_KILL_CLEAR":                 reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PR_MCE_KILL_DEFAULT":               reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_MCE_KILL_EARLY":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_MCE_KILL_GET":                   reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"PR_MCE_KILL_LATE":                  reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PR_MCE_KILL_SET":                   reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_MPX_DISABLE_MANAGEMENT":         reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"PR_MPX_ENABLE_MANAGEMENT":          reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"PR_MTE_TAG_MASK":                   reflect.ValueOf(constant.MakeFromLiteral("524280", token.INT, 0)),
		"PR_MTE_TAG_SHIFT":                  reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"PR_MTE_TCF_ASYNC":                  reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PR_MTE_TCF_MASK":                   reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"PR_MTE_TCF_NONE":                   reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PR_MTE_TCF_SHIFT":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_MTE_TCF_SYNC":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_PAC_APDAKEY":                    reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PR_PAC_APDBKEY":                    reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PR_PAC_APGAKEY":                    reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"PR_PAC_APIAKEY":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_PAC_APIBKEY":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_PAC_GET_ENABLED_KEYS":           reflect.ValueOf(constant.MakeFromLiteral("61", token.INT, 0)),
		"PR_PAC_RESET_KEYS":                 reflect.ValueOf(constant.MakeFromLiteral("54", token.INT, 0)),
		"PR_PAC_SET_ENABLED_KEYS":           reflect.ValueOf(constant.MakeFromLiteral("60", token.INT, 0)),
		"PR_SCHED_CORE":                     reflect.ValueOf(constant.MakeFromLiteral("62", token.INT, 0)),
		"PR_SCHED_CORE_CREATE":              reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_SCHED_CORE_GET":                 reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PR_SCHED_CORE_MAX":                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PR_SCHED_CORE_SCOPE_PROCESS_GROUP": reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_SCHED_CORE_SCOPE_THREAD":        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PR_SCHED_CORE_SCOPE_THREAD_GROUP":  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_SCHED_CORE_SHARE_FROM":          reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"PR_SCHED_CORE_SHARE_TO":            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_SET_CHILD_SUBREAPER":            reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"PR_SET_DUMPABLE":                   reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PR_SET_ENDIAN":                     reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"PR_SET_FPEMU":                      reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"PR_SET_FPEXC":                      reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"PR_SET_FP_MODE":                    reflect.ValueOf(constant.MakeFromLiteral("45", token.INT, 0)),
		"PR_SET_IO_FLUSHER":                 reflect.ValueOf(constant.MakeFromLiteral("57", token.INT, 0)),
		"PR_SET_KEEPCAPS":                   reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PR_SET_MM":                         reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"PR_SET_MM_ARG_END":                 reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"PR_SET_MM_ARG_START":               reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PR_SET_MM_AUXV":                    reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"PR_SET_MM_BRK":                     reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"PR_SET_MM_END_CODE":                reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_SET_MM_END_DATA":                reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PR_SET_MM_ENV_END":                 reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"PR_SET_MM_ENV_START":               reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"PR_SET_MM_EXE_FILE":                reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"PR_SET_MM_MAP":                     reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"PR_SET_MM_MAP_SIZE":                reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"PR_SET_MM_START_BRK":               reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"PR_SET_MM_START_CODE":              reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_SET_MM_START_DATA":              reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"PR_SET_MM_START_STACK":             reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"PR_SET_NAME":                       reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"PR_SET_NO_NEW_PRIVS":               reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"PR_SET_PDEATHSIG":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_SET_PTRACER":                    reflect.ValueOf(constant.MakeFromLiteral("1499557217", token.INT, 0)),
		"PR_SET_PTRACER_ANY":                reflect.ValueOf(constant.MakeFromLiteral("18446744073709551615", token.INT, 0)),
		"PR_SET_SECCOMP":                    reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"PR_SET_SECUREBITS":                 reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"PR_SET_SPECULATION_CTRL":           reflect.ValueOf(constant.MakeFromLiteral("53", token.INT, 0)),
		"PR_SET_SYSCALL_USER_DISPATCH":      reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"PR_SET_TAGGED_ADDR_CTRL":           reflect.ValueOf(constant.MakeFromLiteral("55", token.INT, 0)),
		"PR_SET_THP_DISABLE":                reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"PR_SET_TIMERSLACK":                 reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"PR_SET_TIMING":                     reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"PR_SET_TSC":                        reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"PR_SET_UNALIGN":                    reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"PR_SET_VMA":                        reflect.ValueOf(constant.MakeFromLiteral("1398164801", token.INT, 0)),
		"PR_SET_VMA_ANON_NAME":              reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PR_SPEC_DISABLE":                   reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PR_SPEC_DISABLE_NOEXEC":            reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"PR_SPEC_ENABLE":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_SPEC_FORCE_DISABLE":             reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PR_SPEC_INDIRECT_BRANCH":           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_SPEC_L1D_FLUSH":                 reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_SPEC_NOT_AFFECTED":              reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PR_SPEC_PRCTL":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_SPEC_STORE_BYPASS":              reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PR_SVE_GET_VL":                     reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"PR_SVE_SET_VL":                     reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"PR_SVE_SET_VL_ONEXEC":              reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"PR_SVE_VL_INHERIT":                 reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"PR_SVE_VL_LEN_MASK":                reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"PR_SYS_DISPATCH_OFF":               reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PR_SYS_DISPATCH_ON":                reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_TAGGED_ADDR_ENABLE":             reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_TASK_PERF_EVENTS_DISABLE":       reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"PR_TASK_PERF_EVENTS_ENABLE":        reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"PR_TIMING_STATISTICAL":             reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PR_TIMING_TIMESTAMP":               reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_TSC_ENABLE":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_TSC_SIGSEGV":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PR_UNALIGN_NOPRINT":                reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PR_UNALIGN_SIGBUS":                 reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PTRACE_ATTACH":                     reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"PTRACE_CONT":                       reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"PTRACE_DETACH":                     reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"PTRACE_EVENTMSG_SYSCALL_ENTRY":     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PTRACE_EVENTMSG_SYSCALL_EXIT":      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PTRACE_EVENT_CLONE":                reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"PTRACE_EVENT_EXEC":                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PTRACE_EVENT_EXIT":                 reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"PTRACE_EVENT_FORK":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PTRACE_EVENT_SECCOMP":              reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"PTRACE_EVENT_STOP":                 reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"PTRACE_EVENT_VFORK":                reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PTRACE_EVENT_VFORK_DONE":           reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"PTRACE_GETEVENTMSG":                reflect.ValueOf(constant.MakeFromLiteral("16897", token.INT, 0)),
		"PTRACE_GETREGS":                    reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"PTRACE_GETREGSET":                  reflect.ValueOf(constant.MakeFromLiteral("16900", token.INT, 0)),
		"PTRACE_GETSIGINFO":                 reflect.ValueOf(constant.MakeFromLiteral("16898", token.INT, 0)),
		"PTRACE_GETSIGMASK":                 reflect.ValueOf(constant.MakeFromLiteral("16906", token.INT, 0)),
		"PTRACE_GET_RSEQ_CONFIGURATION":     reflect.ValueOf(constant.MakeFromLiteral("16911", token.INT, 0)),
		"PTRACE_GET_SYSCALL_INFO":           reflect.ValueOf(constant.MakeFromLiteral("16910", token.INT, 0)),
		"PTRACE_INTERRUPT":                  reflect.ValueOf(constant.MakeFromLiteral("16903", token.INT, 0)),
		"PTRACE_KILL":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PTRACE_LISTEN":                     reflect.ValueOf(constant.MakeFromLiteral("16904", token.INT, 0)),
		"PTRACE_O_EXITKILL":                 reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"PTRACE_O_MASK":                     reflect.ValueOf(constant.MakeFromLiteral("3145983", token.INT, 0)),
		"PTRACE_O_SUSPEND_SECCOMP":          reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"PTRACE_O_TRACECLONE":               reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PTRACE_O_TRACEEXEC":                reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"PTRACE_O_TRACEEXIT":                reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"PTRACE_O_TRACEFORK":                reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PTRACE_O_TRACESECCOMP":             reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"PTRACE_O_TRACESYSGOOD":             reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PTRACE_O_TRACEVFORK":               reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PTRACE_O_TRACEVFORKDONE":           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"PTRACE_PEEKDATA":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PTRACE_PEEKSIGINFO":                reflect.ValueOf(constant.MakeFromLiteral("16905", token.INT, 0)),
		"PTRACE_PEEKSIGINFO_SHARED":         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PTRACE_PEEKTEXT":                   reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PTRACE_PEEKUSR":                    reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"PTRACE_POKEDATA":                   reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"PTRACE_POKETEXT":                   reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PTRACE_POKEUSR":                    reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"PTRACE_SECCOMP_GET_FILTER":         reflect.ValueOf(constant.MakeFromLiteral("16908", token.INT, 0)),
		"PTRACE_SECCOMP_GET_METADATA":       reflect.ValueOf(constant.MakeFromLiteral("16909", token.INT, 0)),
		"PTRACE_SEIZE":                      reflect.ValueOf(constant.MakeFromLiteral("16902", token.INT, 0)),
		"PTRACE_SETOPTIONS":                 reflect.ValueOf(constant.MakeFromLiteral("16896", token.INT, 0)),
		"PTRACE_SETREGS":                    reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"PTRACE_SETREGSET":                  reflect.ValueOf(constant.MakeFromLiteral("16901", token.INT, 0)),
		"PTRACE_SETSIGINFO":                 reflect.ValueOf(constant.MakeFromLiteral("16899", token.INT, 0)),
		"PTRACE_SETSIGMASK":                 reflect.ValueOf(constant.MakeFromLiteral("16907", token.INT, 0)),
		"PTRACE_SINGLESTEP":                 reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"PTRACE_SYSCALL":                    reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"PTRACE_SYSCALL_INFO_ENTRY":         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PTRACE_SYSCALL_INFO_EXIT":          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PTRACE_SYSCALL_INFO_NONE":          reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PTRACE_SYSCALL_INFO_SECCOMP":       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"PTRACE_SYSEMU":                     reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"PTRACE_SYSEMU_SINGLESTEP":          reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"PTRACE_TRACEME":                    reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"ParseDirent":                       reflect.ValueOf(syscall.ParseDirent),
		"ParseNetlinkMessage":               reflect.ValueOf(syscall.ParseNetlinkMessage),
		"ParseNetlinkRouteAttr":             reflect.ValueOf(syscall.ParseNetlinkRouteAttr),
		"ParseSocketControlMessage":         reflect.ValueOf(syscall.ParseSocketControlMessage),
		"ParseUnixCredentials":              reflect.ValueOf(syscall.ParseUnixCredentials),
		"ParseUnixRights":                   reflect.ValueOf(syscall.ParseUnixRights),
		"PathMax":                           reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"Pause":                             reflect.ValueOf(syscall.Pause),
		"Pipe":                              reflect.ValueOf(syscall.Pipe),
		"Pipe2":                             reflect.ValueOf(syscall.Pipe2),
		"PivotRoot":                         reflect.ValueOf(syscall.PivotRoot),
		"Pread":                             reflect.ValueOf(syscall.Pread),
		"Pwrite":                            reflect.ValueOf(syscall.Pwrite),
		"RLIMIT_AS":                         reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"RLIMIT_CORE":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RLIMIT_CPU":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RLIMIT_DATA":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RLIMIT_FSIZE":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RLIMIT_NOFILE":                     reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"RLIMIT_STACK":                      reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RLIM_INFINITY":                     reflect.ValueOf(constant.MakeFromLiteral("18446744073709551615", token.INT, 0)),
		"RTAX_ADVMSS":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTAX_CC_ALGO":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTAX_CWND":                         reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"RTAX_FASTOPEN_NO_COOKIE":           reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"RTAX_FEATURES":                     reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"RTAX_FEATURE_ALLFRAG":              reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTAX_FEATURE_ECN":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTAX_FEATURE_MASK":                 reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"RTAX_FEATURE_SACK":                 reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTAX_FEATURE_TIMESTAMP":            reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTAX_HOPLIMIT":                     reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"RTAX_INITCWND":                     reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"RTAX_INITRWND":                     reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"RTAX_LOCK":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTAX_MAX":                          reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"RTAX_MTU":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTAX_QUICKACK":                     reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"RTAX_REORDERING":                   reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"RTAX_RTO_MIN":                      reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"RTAX_RTT":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTAX_RTTVAR":                       reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"RTAX_SSTHRESH":                     reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"RTAX_UNSPEC":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RTAX_WINDOW":                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RTA_ALIGNTO":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTA_CACHEINFO":                     reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"RTA_DST":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTA_FLOW":                          reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"RTA_GATEWAY":                       reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"RTA_IIF":                           reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RTA_MAX":                           reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"RTA_METRICS":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTA_MULTIPATH":                     reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"RTA_OIF":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTA_PREFSRC":                       reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"RTA_PRIORITY":                      reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"RTA_SRC":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTA_TABLE":                         reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"RTA_UNSPEC":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RTCF_DIRECTSRC":                    reflect.ValueOf(constant.MakeFromLiteral("67108864", token.INT, 0)),
		"RTCF_DOREDIRECT":                   reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"RTCF_LOG":                          reflect.ValueOf(constant.MakeFromLiteral("33554432", token.INT, 0)),
		"RTCF_MASQ":                         reflect.ValueOf(constant.MakeFromLiteral("4194304", token.INT, 0)),
		"RTCF_NAT":                          reflect.ValueOf(constant.MakeFromLiteral("8388608", token.INT, 0)),
		"RTCF_VALVE":                        reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"RTF_ADDRCLASSMASK":                 reflect.ValueOf(constant.MakeFromLiteral("4160749568", token.INT, 0)),
		"RTF_ADDRCONF":                      reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"RTF_ALLONLINK":                     reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"RTF_BROADCAST":                     reflect.ValueOf(constant.MakeFromLiteral("268435456", token.INT, 0)),
		"RTF_CACHE":                         reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"RTF_DEFAULT":                       reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"RTF_DYNAMIC":                       reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTF_FLOW":                          reflect.ValueOf(constant.MakeFromLiteral("33554432", token.INT, 0)),
		"RTF_GATEWAY":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTF_HOST":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTF_INTERFACE":                     reflect.ValueOf(constant.MakeFromLiteral("1073741824", token.INT, 0)),
		"RTF_IRTT":                          reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"RTF_LINKRT":                        reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"RTF_LOCAL":                         reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"RTF_MODIFIED":                      reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"RTF_MSS":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"RTF_MTU":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"RTF_MULTICAST":                     reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"RTF_NAT":                           reflect.ValueOf(constant.MakeFromLiteral("134217728", token.INT, 0)),
		"RTF_NOFORWARD":                     reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"RTF_NONEXTHOP":                     reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"RTF_NOPMTUDISC":                    reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"RTF_POLICY":                        reflect.ValueOf(constant.MakeFromLiteral("67108864", token.INT, 0)),
		"RTF_REINSTATE":                     reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTF_REJECT":                        reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"RTF_STATIC":                        reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"RTF_THROW":                         reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"RTF_UP":                            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTF_WINDOW":                        reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"RTF_XRESOLVE":                      reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"RTM_BASE":                          reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTM_DELACTION":                     reflect.ValueOf(constant.MakeFromLiteral("49", token.INT, 0)),
		"RTM_DELADDR":                       reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"RTM_DELADDRLABEL":                  reflect.ValueOf(constant.MakeFromLiteral("73", token.INT, 0)),
		"RTM_DELCHAIN":                      reflect.ValueOf(constant.MakeFromLiteral("101", token.INT, 0)),
		"RTM_DELLINK":                       reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"RTM_DELLINKPROP":                   reflect.ValueOf(constant.MakeFromLiteral("109", token.INT, 0)),
		"RTM_DELMDB":                        reflect.ValueOf(constant.MakeFromLiteral("85", token.INT, 0)),
		"RTM_DELNEIGH":                      reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"RTM_DELNETCONF":                    reflect.ValueOf(constant.MakeFromLiteral("81", token.INT, 0)),
		"RTM_DELNEXTHOP":                    reflect.ValueOf(constant.MakeFromLiteral("105", token.INT, 0)),
		"RTM_DELNEXTHOPBUCKET":              reflect.ValueOf(constant.MakeFromLiteral("117", token.INT, 0)),
		"RTM_DELNSID":                       reflect.ValueOf(constant.MakeFromLiteral("89", token.INT, 0)),
		"RTM_DELQDISC":                      reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"RTM_DELROUTE":                      reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"RTM_DELRULE":                       reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"RTM_DELTCLASS":                     reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"RTM_DELTFILTER":                    reflect.ValueOf(constant.MakeFromLiteral("45", token.INT, 0)),
		"RTM_DELVLAN":                       reflect.ValueOf(constant.MakeFromLiteral("113", token.INT, 0)),
		"RTM_F_CLONED":                      reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"RTM_F_EQUALIZE":                    reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"RTM_F_FIB_MATCH":                   reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"RTM_F_LOOKUP_TABLE":                reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"RTM_F_NOTIFY":                      reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"RTM_F_OFFLOAD":                     reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"RTM_F_OFFLOAD_FAILED":              reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"RTM_F_PREFIX":                      reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"RTM_F_TRAP":                        reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"RTM_GETACTION":                     reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"RTM_GETADDR":                       reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"RTM_GETADDRLABEL":                  reflect.ValueOf(constant.MakeFromLiteral("74", token.INT, 0)),
		"RTM_GETANYCAST":                    reflect.ValueOf(constant.MakeFromLiteral("62", token.INT, 0)),
		"RTM_GETCHAIN":                      reflect.ValueOf(constant.MakeFromLiteral("102", token.INT, 0)),
		"RTM_GETDCB":                        reflect.ValueOf(constant.MakeFromLiteral("78", token.INT, 0)),
		"RTM_GETLINK":                       reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"RTM_GETLINKPROP":                   reflect.ValueOf(constant.MakeFromLiteral("110", token.INT, 0)),
		"RTM_GETMDB":                        reflect.ValueOf(constant.MakeFromLiteral("86", token.INT, 0)),
		"RTM_GETMULTICAST":                  reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"RTM_GETNEIGH":                      reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"RTM_GETNEIGHTBL":                   reflect.ValueOf(constant.MakeFromLiteral("66", token.INT, 0)),
		"RTM_GETNETCONF":                    reflect.ValueOf(constant.MakeFromLiteral("82", token.INT, 0)),
		"RTM_GETNEXTHOP":                    reflect.ValueOf(constant.MakeFromLiteral("106", token.INT, 0)),
		"RTM_GETNEXTHOPBUCKET":              reflect.ValueOf(constant.MakeFromLiteral("118", token.INT, 0)),
		"RTM_GETNSID":                       reflect.ValueOf(constant.MakeFromLiteral("90", token.INT, 0)),
		"RTM_GETQDISC":                      reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"RTM_GETROUTE":                      reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"RTM_GETRULE":                       reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"RTM_GETSTATS":                      reflect.ValueOf(constant.MakeFromLiteral("94", token.INT, 0)),
		"RTM_GETTCLASS":                     reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"RTM_GETTFILTER":                    reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"RTM_GETVLAN":                       reflect.ValueOf(constant.MakeFromLiteral("114", token.INT, 0)),
		"RTM_MAX":                           reflect.ValueOf(constant.MakeFromLiteral("119", token.INT, 0)),
		"RTM_NEWACTION":                     reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"RTM_NEWADDR":                       reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"RTM_NEWADDRLABEL":                  reflect.ValueOf(constant.MakeFromLiteral("72", token.INT, 0)),
		"RTM_NEWCACHEREPORT":                reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"RTM_NEWCHAIN":                      reflect.ValueOf(constant.MakeFromLiteral("100", token.INT, 0)),
		"RTM_NEWLINK":                       reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTM_NEWLINKPROP":                   reflect.ValueOf(constant.MakeFromLiteral("108", token.INT, 0)),
		"RTM_NEWMDB":                        reflect.ValueOf(constant.MakeFromLiteral("84", token.INT, 0)),
		"RTM_NEWNDUSEROPT":                  reflect.ValueOf(constant.MakeFromLiteral("68", token.INT, 0)),
		"RTM_NEWNEIGH":                      reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"RTM_NEWNEIGHTBL":                   reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"RTM_NEWNETCONF":                    reflect.ValueOf(constant.MakeFromLiteral("80", token.INT, 0)),
		"RTM_NEWNEXTHOP":                    reflect.ValueOf(constant.MakeFromLiteral("104", token.INT, 0)),
		"RTM_NEWNEXTHOPBUCKET":              reflect.ValueOf(constant.MakeFromLiteral("116", token.INT, 0)),
		"RTM_NEWNSID":                       reflect.ValueOf(constant.MakeFromLiteral("88", token.INT, 0)),
		"RTM_NEWNVLAN":                      reflect.ValueOf(constant.MakeFromLiteral("112", token.INT, 0)),
		"RTM_NEWPREFIX":                     reflect.ValueOf(constant.MakeFromLiteral("52", token.INT, 0)),
		"RTM_NEWQDISC":                      reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"RTM_NEWROUTE":                      reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"RTM_NEWRULE":                       reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"RTM_NEWSTATS":                      reflect.ValueOf(constant.MakeFromLiteral("92", token.INT, 0)),
		"RTM_NEWTCLASS":                     reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"RTM_NEWTFILTER":                    reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"RTM_NR_FAMILIES":                   reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"RTM_NR_MSGTYPES":                   reflect.ValueOf(constant.MakeFromLiteral("104", token.INT, 0)),
		"RTM_SETDCB":                        reflect.ValueOf(constant.MakeFromLiteral("79", token.INT, 0)),
		"RTM_SETLINK":                       reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"RTM_SETNEIGHTBL":                   reflect.ValueOf(constant.MakeFromLiteral("67", token.INT, 0)),
		"RTNH_ALIGNTO":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTNH_COMPARE_MASK":                 reflect.ValueOf(constant.MakeFromLiteral("89", token.INT, 0)),
		"RTNH_F_DEAD":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTNH_F_LINKDOWN":                   reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTNH_F_OFFLOAD":                    reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTNH_F_ONLINK":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTNH_F_PERVASIVE":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTNH_F_TRAP":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"RTNH_F_UNRESOLVED":                 reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"RTNLGRP_IPV4_IFADDR":               reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"RTNLGRP_IPV4_MROUTE":               reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"RTNLGRP_IPV4_ROUTE":                reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"RTNLGRP_IPV4_RULE":                 reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTNLGRP_IPV6_IFADDR":               reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"RTNLGRP_IPV6_IFINFO":               reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"RTNLGRP_IPV6_MROUTE":               reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"RTNLGRP_IPV6_PREFIX":               reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"RTNLGRP_IPV6_ROUTE":                reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"RTNLGRP_IPV6_RULE":                 reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"RTNLGRP_LINK":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTNLGRP_ND_USEROPT":                reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"RTNLGRP_NEIGH":                     reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RTNLGRP_NONE":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RTNLGRP_NOTIFY":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTNLGRP_TC":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTN_ANYCAST":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTN_BLACKHOLE":                     reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"RTN_BROADCAST":                     reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RTN_LOCAL":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTN_MAX":                           reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"RTN_MULTICAST":                     reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"RTN_NAT":                           reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"RTN_PROHIBIT":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTN_THROW":                         reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"RTN_UNICAST":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTN_UNREACHABLE":                   reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"RTN_UNSPEC":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RTN_XRESOLVE":                      reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"RTPROT_BABEL":                      reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"RTPROT_BGP":                        reflect.ValueOf(constant.MakeFromLiteral("186", token.INT, 0)),
		"RTPROT_BIRD":                       reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"RTPROT_BOOT":                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RTPROT_DHCP":                       reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTPROT_DNROUTED":                   reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"RTPROT_EIGRP":                      reflect.ValueOf(constant.MakeFromLiteral("192", token.INT, 0)),
		"RTPROT_GATED":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTPROT_ISIS":                       reflect.ValueOf(constant.MakeFromLiteral("187", token.INT, 0)),
		"RTPROT_KEEPALIVED":                 reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"RTPROT_KERNEL":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTPROT_MROUTED":                    reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"RTPROT_MRT":                        reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"RTPROT_NTK":                        reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"RTPROT_OPENR":                      reflect.ValueOf(constant.MakeFromLiteral("99", token.INT, 0)),
		"RTPROT_OSPF":                       reflect.ValueOf(constant.MakeFromLiteral("188", token.INT, 0)),
		"RTPROT_RA":                         reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"RTPROT_REDIRECT":                   reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTPROT_RIP":                        reflect.ValueOf(constant.MakeFromLiteral("189", token.INT, 0)),
		"RTPROT_STATIC":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTPROT_UNSPEC":                     reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RTPROT_XORP":                       reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"RTPROT_ZEBRA":                      reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"RT_CLASS_DEFAULT":                  reflect.ValueOf(constant.MakeFromLiteral("253", token.INT, 0)),
		"RT_CLASS_LOCAL":                    reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"RT_CLASS_MAIN":                     reflect.ValueOf(constant.MakeFromLiteral("254", token.INT, 0)),
		"RT_CLASS_MAX":                      reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"RT_CLASS_UNSPEC":                   reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RT_SCOPE_HOST":                     reflect.ValueOf(constant.MakeFromLiteral("254", token.INT, 0)),
		"RT_SCOPE_LINK":                     reflect.ValueOf(constant.MakeFromLiteral("253", token.INT, 0)),
		"RT_SCOPE_NOWHERE":                  reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"RT_SCOPE_SITE":                     reflect.ValueOf(constant.MakeFromLiteral("200", token.INT, 0)),
		"RT_SCOPE_UNIVERSE":                 reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RT_TABLE_COMPAT":                   reflect.ValueOf(constant.MakeFromLiteral("252", token.INT, 0)),
		"RT_TABLE_DEFAULT":                  reflect.ValueOf(constant.MakeFromLiteral("253", token.INT, 0)),
		"RT_TABLE_LOCAL":                    reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"RT_TABLE_MAIN":                     reflect.ValueOf(constant.MakeFromLiteral("254", token.INT, 0)),
		"RT_TABLE_MAX":                      reflect.ValueOf(constant.MakeFromLiteral("4294967295", token.INT, 0)),
		"RT_TABLE_UNSPEC":                   reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RUSAGE_CHILDREN":                   reflect.ValueOf(constant.MakeFromLiteral("-1", token.INT, 0)),
		"RUSAGE_SELF":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RUSAGE_THREAD":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"Read":                              reflect.ValueOf(syscall.Read),
		"ReadDirent":                        reflect.ValueOf(syscall.ReadDirent),
		"Readlink":                          reflect.ValueOf(syscall.Readlink),
		"Recvfrom":                          reflect.ValueOf(syscall.Recvfrom),
		"Recvmsg":                           reflect.ValueOf(syscall.Recvmsg),
		"Removexattr":                       reflect.ValueOf(syscall.Removexattr),
		"Rename":                            reflect.ValueOf(syscall.Rename),
		"Renameat":                          reflect.ValueOf(syscall.Renameat),
		"Rmdir":                             reflect.ValueOf(syscall.Rmdir),
		"SCM_CREDENTIALS":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SCM_RIGHTS":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SCM_TIMESTAMP":                     reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"SCM_TIMESTAMPING":                  reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"SCM_TIMESTAMPING_OPT_STATS":        reflect.ValueOf(constant.MakeFromLiteral("54", token.INT, 0)),
		"SCM_TIMESTAMPING_PKTINFO":          reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"SCM_TIMESTAMPNS":                   reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"SCM_TXTIME":                        reflect.ValueOf(constant.MakeFromLiteral("61", token.INT, 0)),
		"SCM_WIFI_STATUS":                   reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"SHUT_RD":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"SHUT_RDWR":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SHUT_WR":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SIGABRT":                           reflect.ValueOf(syscall.SIGABRT),
		"SIGALRM":                           reflect.ValueOf(syscall.SIGALRM),
		"SIGBUS":                            reflect.ValueOf(syscall.SIGBUS),
		"SIGCHLD":                           reflect.ValueOf(syscall.SIGCHLD),
		"SIGCLD":                            reflect.ValueOf(syscall.SIGCLD),
		"SIGCONT":                           reflect.ValueOf(syscall.SIGCONT),
		"SIGFPE":                            reflect.ValueOf(syscall.SIGFPE),
		"SIGHUP":                            reflect.ValueOf(syscall.SIGHUP),
		"SIGILL":                            reflect.ValueOf(syscall.SIGILL),
		"SIGINT":                            reflect.ValueOf(syscall.SIGINT),
		"SIGIO":                             reflect.ValueOf(syscall.SIGIO),
		"SIGIOT":                            reflect.ValueOf(syscall.SIGIOT),
		"SIGKILL":                           reflect.ValueOf(syscall.SIGKILL),
		"SIGPIPE":                           reflect.ValueOf(syscall.SIGPIPE),
		"SIGPOLL":                           reflect.ValueOf(syscall.SIGPOLL),
		"SIGPROF":                           reflect.ValueOf(syscall.SIGPROF),
		"SIGPWR":                            reflect.ValueOf(syscall.SIGPWR),
		"SIGQUIT":                           reflect.ValueOf(syscall.SIGQUIT),
		"SIGSEGV":                           reflect.ValueOf(syscall.SIGSEGV),
		"SIGSTKFLT":                         reflect.ValueOf(syscall.SIGSTKFLT),
		"SIGSTOP":                           reflect.ValueOf(syscall.SIGSTOP),
		"SIGSYS":                            reflect.ValueOf(syscall.SIGSYS),
		"SIGTERM":                           reflect.ValueOf(syscall.SIGTERM),
		"SIGTRAP":                           reflect.ValueOf(syscall.SIGTRAP),
		"SIGTSTP":                           reflect.ValueOf(syscall.SIGTSTP),
		"SIGTTIN":                           reflect.ValueOf(syscall.SIGTTIN),
		"SIGTTOU":                           reflect.ValueOf(syscall.SIGTTOU),
		"SIGURG":                            reflect.ValueOf(syscall.SIGURG),
		"SIGUSR1":                           reflect.ValueOf(syscall.SIGUSR1),
		"SIGUSR2":                           reflect.ValueOf(syscall.SIGUSR2),
		"SIGVTALRM":                         reflect.ValueOf(syscall.SIGVTALRM),
		"SIGWINCH":                          reflect.ValueOf(syscall.SIGWINCH),
		"SIGXCPU":                           reflect.ValueOf(syscall.SIGXCPU),
		"SIGXFSZ":                           reflect.ValueOf(syscall.SIGXFSZ),
		"SIOCADDDLCI":                       reflect.ValueOf(constant.MakeFromLiteral("35200", token.INT, 0)),
		"SIOCADDMULTI":                      reflect.ValueOf(constant.MakeFromLiteral("35121", token.INT, 0)),
		"SIOCADDRT":                         reflect.ValueOf(constant.MakeFromLiteral("35083", token.INT, 0)),
		"SIOCATMARK":                        reflect.ValueOf(constant.MakeFromLiteral("35077", token.INT, 0)),
		"SIOCDARP":                          reflect.ValueOf(constant.MakeFromLiteral("35155", token.INT, 0)),
		"SIOCDELDLCI":                       reflect.ValueOf(constant.MakeFromLiteral("35201", token.INT, 0)),
		"SIOCDELMULTI":                      reflect.ValueOf(constant.MakeFromLiteral("35122", token.INT, 0)),
		"SIOCDELRT":                         reflect.ValueOf(constant.MakeFromLiteral("35084", token.INT, 0)),
		"SIOCDEVPRIVATE":                    reflect.ValueOf(constant.MakeFromLiteral("35312", token.INT, 0)),
		"SIOCDIFADDR":                       reflect.ValueOf(constant.MakeFromLiteral("35126", token.INT, 0)),
		"SIOCDRARP":                         reflect.ValueOf(constant.MakeFromLiteral("35168", token.INT, 0)),
		"SIOCGARP":                          reflect.ValueOf(constant.MakeFromLiteral("35156", token.INT, 0)),
		"SIOCGIFADDR":                       reflect.ValueOf(constant.MakeFromLiteral("35093", token.INT, 0)),
		"SIOCGIFBR":                         reflect.ValueOf(constant.MakeFromLiteral("35136", token.INT, 0)),
		"SIOCGIFBRDADDR":                    reflect.ValueOf(constant.MakeFromLiteral("35097", token.INT, 0)),
		"SIOCGIFCONF":                       reflect.ValueOf(constant.MakeFromLiteral("35090", token.INT, 0)),
		"SIOCGIFCOUNT":                      reflect.ValueOf(constant.MakeFromLiteral("35128", token.INT, 0)),
		"SIOCGIFDSTADDR":                    reflect.ValueOf(constant.MakeFromLiteral("35095", token.INT, 0)),
		"SIOCGIFENCAP":                      reflect.ValueOf(constant.MakeFromLiteral("35109", token.INT, 0)),
		"SIOCGIFFLAGS":                      reflect.ValueOf(constant.MakeFromLiteral("35091", token.INT, 0)),
		"SIOCGIFHWADDR":                     reflect.ValueOf(constant.MakeFromLiteral("35111", token.INT, 0)),
		"SIOCGIFINDEX":                      reflect.ValueOf(constant.MakeFromLiteral("35123", token.INT, 0)),
		"SIOCGIFMAP":                        reflect.ValueOf(constant.MakeFromLiteral("35184", token.INT, 0)),
		"SIOCGIFMEM":                        reflect.ValueOf(constant.MakeFromLiteral("35103", token.INT, 0)),
		"SIOCGIFMETRIC":                     reflect.ValueOf(constant.MakeFromLiteral("35101", token.INT, 0)),
		"SIOCGIFMTU":                        reflect.ValueOf(constant.MakeFromLiteral("35105", token.INT, 0)),
		"SIOCGIFNAME":                       reflect.ValueOf(constant.MakeFromLiteral("35088", token.INT, 0)),
		"SIOCGIFNETMASK":                    reflect.ValueOf(constant.MakeFromLiteral("35099", token.INT, 0)),
		"SIOCGIFPFLAGS":                     reflect.ValueOf(constant.MakeFromLiteral("35125", token.INT, 0)),
		"SIOCGIFSLAVE":                      reflect.ValueOf(constant.MakeFromLiteral("35113", token.INT, 0)),
		"SIOCGIFTXQLEN":                     reflect.ValueOf(constant.MakeFromLiteral("35138", token.INT, 0)),
		"SIOCGPGRP":                         reflect.ValueOf(constant.MakeFromLiteral("35076", token.INT, 0)),
		"SIOCGRARP":                         reflect.ValueOf(constant.MakeFromLiteral("35169", token.INT, 0)),
		"SIOCGSTAMPNS_OLD":                  reflect.ValueOf(constant.MakeFromLiteral("35079", token.INT, 0)),
		"SIOCGSTAMP_OLD":                    reflect.ValueOf(constant.MakeFromLiteral("35078", token.INT, 0)),
		"SIOCPROTOPRIVATE":                  reflect.ValueOf(constant.MakeFromLiteral("35296", token.INT, 0)),
		"SIOCRTMSG":                         reflect.ValueOf(constant.MakeFromLiteral("35085", token.INT, 0)),
		"SIOCSARP":                          reflect.ValueOf(constant.MakeFromLiteral("35157", token.INT, 0)),
		"SIOCSIFADDR":                       reflect.ValueOf(constant.MakeFromLiteral("35094", token.INT, 0)),
		"SIOCSIFBR":                         reflect.ValueOf(constant.MakeFromLiteral("35137", token.INT, 0)),
		"SIOCSIFBRDADDR":                    reflect.ValueOf(constant.MakeFromLiteral("35098", token.INT, 0)),
		"SIOCSIFDSTADDR":                    reflect.ValueOf(constant.MakeFromLiteral("35096", token.INT, 0)),
		"SIOCSIFENCAP":                      reflect.ValueOf(constant.MakeFromLiteral("35110", token.INT, 0)),
		"SIOCSIFFLAGS":                      reflect.ValueOf(constant.MakeFromLiteral("35092", token.INT, 0)),
		"SIOCSIFHWADDR":                     reflect.ValueOf(constant.MakeFromLiteral("35108", token.INT, 0)),
		"SIOCSIFHWBROADCAST":                reflect.ValueOf(constant.MakeFromLiteral("35127", token.INT, 0)),
		"SIOCSIFLINK":                       reflect.ValueOf(constant.MakeFromLiteral("35089", token.INT, 0)),
		"SIOCSIFMAP":                        reflect.ValueOf(constant.MakeFromLiteral("35185", token.INT, 0)),
		"SIOCSIFMEM":                        reflect.ValueOf(constant.MakeFromLiteral("35104", token.INT, 0)),
		"SIOCSIFMETRIC":                     reflect.ValueOf(constant.MakeFromLiteral("35102", token.INT, 0)),
		"SIOCSIFMTU":                        reflect.ValueOf(constant.MakeFromLiteral("35106", token.INT, 0)),
		"SIOCSIFNAME":                       reflect.ValueOf(constant.MakeFromLiteral("35107", token.INT, 0)),
		"SIOCSIFNETMASK":                    reflect.ValueOf(constant.MakeFromLiteral("35100", token.INT, 0)),
		"SIOCSIFPFLAGS":                     reflect.ValueOf(constant.MakeFromLiteral("35124", token.INT, 0)),
		"SIOCSIFSLAVE":                      reflect.ValueOf(constant.MakeFromLiteral("35120", token.INT, 0)),
		"SIOCSIFTXQLEN":                     reflect.ValueOf(constant.MakeFromLiteral("35139", token.INT, 0)),
		"SIOCSPGRP":                         reflect.ValueOf(constant.MakeFromLiteral("35074", token.INT, 0)),
		"SIOCSRARP":                         reflect.ValueOf(constant.MakeFromLiteral("35170", token.INT, 0)),
		"SOCK_BUF_LOCK_MASK":                reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"SOCK_CLOEXEC":                      reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"SOCK_DCCP":                         reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"SOCK_DGRAM":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SOCK_NONBLOCK":                     reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"SOCK_PACKET":                       reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"SOCK_RAW":                          reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"SOCK_RCVBUF_LOCK":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SOCK_RDM":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SOCK_SEQPACKET":                    reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"SOCK_SNDBUF_LOCK":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SOCK_STREAM":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SOL_AAL":                           reflect.ValueOf(constant.MakeFromLiteral("265", token.INT, 0)),
		"SOL_ALG":                           reflect.ValueOf(constant.MakeFromLiteral("279", token.INT, 0)),
		"SOL_ATM":                           reflect.ValueOf(constant.MakeFromLiteral("264", token.INT, 0)),
		"SOL_BLUETOOTH":                     reflect.ValueOf(constant.MakeFromLiteral("274", token.INT, 0)),
		"SOL_CAIF":                          reflect.ValueOf(constant.MakeFromLiteral("278", token.INT, 0)),
		"SOL_DCCP":                          reflect.ValueOf(constant.MakeFromLiteral("269", token.INT, 0)),
		"SOL_DECNET":                        reflect.ValueOf(constant.MakeFromLiteral("261", token.INT, 0)),
		"SOL_ICMPV6":                        reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"SOL_IP":                            reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"SOL_IPV6":                          reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"SOL_IRDA":                          reflect.ValueOf(constant.MakeFromLiteral("266", token.INT, 0)),
		"SOL_IUCV":                          reflect.ValueOf(constant.MakeFromLiteral("277", token.INT, 0)),
		"SOL_KCM":                           reflect.ValueOf(constant.MakeFromLiteral("281", token.INT, 0)),
		"SOL_LLC":                           reflect.ValueOf(constant.MakeFromLiteral("268", token.INT, 0)),
		"SOL_NETBEUI":                       reflect.ValueOf(constant.MakeFromLiteral("267", token.INT, 0)),
		"SOL_NETLINK":                       reflect.ValueOf(constant.MakeFromLiteral("270", token.INT, 0)),
		"SOL_NFC":                           reflect.ValueOf(constant.MakeFromLiteral("280", token.INT, 0)),
		"SOL_PACKET":                        reflect.ValueOf(constant.MakeFromLiteral("263", token.INT, 0)),
		"SOL_PNPIPE":                        reflect.ValueOf(constant.MakeFromLiteral("275", token.INT, 0)),
		"SOL_PPPOL2TP":                      reflect.ValueOf(constant.MakeFromLiteral("273", token.INT, 0)),
		"SOL_RAW":                           reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"SOL_RDS":                           reflect.ValueOf(constant.MakeFromLiteral("276", token.INT, 0)),
		"SOL_RXRPC":                         reflect.ValueOf(constant.MakeFromLiteral("272", token.INT, 0)),
		"SOL_SOCKET":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SOL_TCP":                           reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"SOL_TIPC":                          reflect.ValueOf(constant.MakeFromLiteral("271", token.INT, 0)),
		"SOL_TLS":                           reflect.ValueOf(constant.MakeFromLiteral("282", token.INT, 0)),
		"SOL_X25":                           reflect.ValueOf(constant.MakeFromLiteral("262", token.INT, 0)),
		"SOL_XDP":                           reflect.ValueOf(constant.MakeFromLiteral("283", token.INT, 0)),
		"SOMAXCONN":                         reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"SO_ACCEPTCONN":                     reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"SO_ATTACH_BPF":                     reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"SO_ATTACH_FILTER":                  reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"SO_ATTACH_REUSEPORT_CBPF":          reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"SO_ATTACH_REUSEPORT_EBPF":          reflect.ValueOf(constant.MakeFromLiteral("52", token.INT, 0)),
		"SO_BINDTODEVICE":                   reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"SO_BINDTOIFINDEX":                  reflect.ValueOf(constant.MakeFromLiteral("62", token.INT, 0)),
		"SO_BPF_EXTENSIONS":                 reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"SO_BROADCAST":                      reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"SO_BSDCOMPAT":                      reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"SO_BUF_LOCK":                       reflect.ValueOf(constant.MakeFromLiteral("72", token.INT, 0)),
		"SO_BUSY_POLL":                      reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"SO_BUSY_POLL_BUDGET":               reflect.ValueOf(constant.MakeFromLiteral("70", token.INT, 0)),
		"SO_CNX_ADVICE":                     reflect.ValueOf(constant.MakeFromLiteral("53", token.INT, 0)),
		"SO_COOKIE":                         reflect.ValueOf(constant.MakeFromLiteral("57", token.INT, 0)),
		"SO_DEBUG":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SO_DETACH_BPF":                     reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"SO_DETACH_FILTER":                  reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"SO_DETACH_REUSEPORT_BPF":           reflect.ValueOf(constant.MakeFromLiteral("68", token.INT, 0)),
		"SO_DOMAIN":                         reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"SO_DONTROUTE":                      reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"SO_ERROR":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SO_GET_FILTER":                     reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"SO_INCOMING_CPU":                   reflect.ValueOf(constant.MakeFromLiteral("49", token.INT, 0)),
		"SO_INCOMING_NAPI_ID":               reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"SO_KEEPALIVE":                      reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"SO_LINGER":                         reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"SO_LOCK_FILTER":                    reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"SO_MARK":                           reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"SO_MAX_PACING_RATE":                reflect.ValueOf(constant.MakeFromLiteral("47", token.INT, 0)),
		"SO_MEMINFO":                        reflect.ValueOf(constant.MakeFromLiteral("55", token.INT, 0)),
		"SO_NETNS_COOKIE":                   reflect.ValueOf(constant.MakeFromLiteral("71", token.INT, 0)),
		"SO_NOFCS":                          reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"SO_NO_CHECK":                       reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"SO_OOBINLINE":                      reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"SO_PASSCRED":                       reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SO_PASSSEC":                        reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"SO_PEEK_OFF":                       reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"SO_PEERCRED":                       reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"SO_PEERGROUPS":                     reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"SO_PEERNAME":                       reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"SO_PEERSEC":                        reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"SO_PREFER_BUSY_POLL":               reflect.ValueOf(constant.MakeFromLiteral("69", token.INT, 0)),
		"SO_PRIORITY":                       reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"SO_PROTOCOL":                       reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"SO_RCVBUF":                         reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SO_RCVBUFFORCE":                    reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"SO_RCVLOWAT":                       reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"SO_RCVTIMEO":                       reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SO_RCVTIMEO_NEW":                   reflect.ValueOf(constant.MakeFromLiteral("66", token.INT, 0)),
		"SO_RCVTIMEO_OLD":                   reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SO_RESERVE_MEM":                    reflect.ValueOf(constant.MakeFromLiteral("73", token.INT, 0)),
		"SO_REUSEADDR":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SO_REUSEPORT":                      reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"SO_RXQ_OVFL":                       reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"SO_SECURITY_AUTHENTICATION":        reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"SO_SECURITY_ENCRYPTION_NETWORK":    reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"SO_SECURITY_ENCRYPTION_TRANSPORT":  reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"SO_SELECT_ERR_QUEUE":               reflect.ValueOf(constant.MakeFromLiteral("45", token.INT, 0)),
		"SO_SNDBUF":                         reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"SO_SNDBUFFORCE":                    reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SO_SNDLOWAT":                       reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"SO_SNDTIMEO":                       reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"SO_SNDTIMEO_NEW":                   reflect.ValueOf(constant.MakeFromLiteral("67", token.INT, 0)),
		"SO_SNDTIMEO_OLD":                   reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"SO_TIMESTAMP":                      reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"SO_TIMESTAMPING":                   reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"SO_TIMESTAMPING_NEW":               reflect.ValueOf(constant.MakeFromLiteral("65", token.INT, 0)),
		"SO_TIMESTAMPING_OLD":               reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"SO_TIMESTAMPNS":                    reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"SO_TIMESTAMPNS_NEW":                reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"SO_TIMESTAMPNS_OLD":                reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"SO_TIMESTAMP_NEW":                  reflect.ValueOf(constant.MakeFromLiteral("63", token.INT, 0)),
		"SO_TIMESTAMP_OLD":                  reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"SO_TXTIME":                         reflect.ValueOf(constant.MakeFromLiteral("61", token.INT, 0)),
		"SO_TYPE":                           reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"SO_WIFI_STATUS":                    reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"SO_ZEROCOPY":                       reflect.ValueOf(constant.MakeFromLiteral("60", token.INT, 0)),
		"SYS_ACCEPT":                        reflect.ValueOf(constant.MakeFromLiteral("202", token.INT, 0)),
		"SYS_ACCEPT4":                       reflect.ValueOf(constant.MakeFromLiteral("242", token.INT, 0)),
		"SYS_ACCT":                          reflect.ValueOf(constant.MakeFromLiteral("89", token.INT, 0)),
		"SYS_ADD_KEY":                       reflect.ValueOf(constant.MakeFromLiteral("217", token.INT, 0)),
		"SYS_ADJTIMEX":                      reflect.ValueOf(constant.MakeFromLiteral("171", token.INT, 0)),
		"SYS_ARCH_SPECIFIC_SYSCALL":         reflect.ValueOf(constant.MakeFromLiteral("244", token.INT, 0)),
		"SYS_BIND":                          reflect.ValueOf(constant.MakeFromLiteral("200", token.INT, 0)),
		"SYS_BPF":                           reflect.ValueOf(constant.MakeFromLiteral("280", token.INT, 0)),
		"SYS_BRK":                           reflect.ValueOf(constant.MakeFromLiteral("214", token.INT, 0)),
		"SYS_CAPGET":                        reflect.ValueOf(constant.MakeFromLiteral("90", token.INT, 0)),
		"SYS_CAPSET":                        reflect.ValueOf(constant.MakeFromLiteral("91", token.INT, 0)),
		"SYS_CHDIR":                         reflect.ValueOf(constant.MakeFromLiteral("49", token.INT, 0)),
		"SYS_CHROOT":                        reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"SYS_CLOCK_ADJTIME":                 reflect.ValueOf(constant.MakeFromLiteral("266", token.INT, 0)),
		"SYS_CLOCK_GETRES":                  reflect.ValueOf(constant.MakeFromLiteral("114", token.INT, 0)),
		"SYS_CLOCK_GETTIME":                 reflect.ValueOf(constant.MakeFromLiteral("113", token.INT, 0)),
		"SYS_CLOCK_NANOSLEEP":               reflect.ValueOf(constant.MakeFromLiteral("115", token.INT, 0)),
		"SYS_CLOCK_SETTIME":                 reflect.ValueOf(constant.MakeFromLiteral("112", token.INT, 0)),
		"SYS_CLONE":                         reflect.ValueOf(constant.MakeFromLiteral("220", token.INT, 0)),
		"SYS_CLOSE":                         reflect.ValueOf(constant.MakeFromLiteral("57", token.INT, 0)),
		"SYS_CLOSE_RANGE":                   reflect.ValueOf(constant.MakeFromLiteral("436", token.INT, 0)),
		"SYS_CONNECT":                       reflect.ValueOf(constant.MakeFromLiteral("203", token.INT, 0)),
		"SYS_COPY_FILE_RANGE":               reflect.ValueOf(constant.MakeFromLiteral("285", token.INT, 0)),
		"SYS_DELETE_MODULE":                 reflect.ValueOf(constant.MakeFromLiteral("106", token.INT, 0)),
		"SYS_DUP":                           reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"SYS_DUP3":                          reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"SYS_EPOLL_CREATE1":                 reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SYS_EPOLL_CTL":                     reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"SYS_EPOLL_PWAIT":                   reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"SYS_EPOLL_PWAIT2":                  reflect.ValueOf(constant.MakeFromLiteral("441", token.INT, 0)),
		"SYS_EVENTFD2":                      reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"SYS_EXECVE":                        reflect.ValueOf(constant.MakeFromLiteral("221", token.INT, 0)),
		"SYS_EXECVEAT":                      reflect.ValueOf(constant.MakeFromLiteral("281", token.INT, 0)),
		"SYS_EXIT":                          reflect.ValueOf(constant.MakeFromLiteral("93", token.INT, 0)),
		"SYS_EXIT_GROUP":                    reflect.ValueOf(constant.MakeFromLiteral("94", token.INT, 0)),
		"SYS_FACCESSAT":                     reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"SYS_FACCESSAT2":                    reflect.ValueOf(constant.MakeFromLiteral("439", token.INT, 0)),
		"SYS_FADVISE64":                     reflect.ValueOf(constant.MakeFromLiteral("223", token.INT, 0)),
		"SYS_FALLOCATE":                     reflect.ValueOf(constant.MakeFromLiteral("47", token.INT, 0)),
		"SYS_FANOTIFY_INIT":                 reflect.ValueOf(constant.MakeFromLiteral("262", token.INT, 0)),
		"SYS_FANOTIFY_MARK":                 reflect.ValueOf(constant.MakeFromLiteral("263", token.INT, 0)),
		"SYS_FCHDIR":                        reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"SYS_FCHMOD":                        reflect.ValueOf(constant.MakeFromLiteral("52", token.INT, 0)),
		"SYS_FCHMODAT":                      reflect.ValueOf(constant.MakeFromLiteral("53", token.INT, 0)),
		"SYS_FCHOWN":                        reflect.ValueOf(constant.MakeFromLiteral("55", token.INT, 0)),
		"SYS_FCHOWNAT":                      reflect.ValueOf(constant.MakeFromLiteral("54", token.INT, 0)),
		"SYS_FCNTL":                         reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"SYS_FDATASYNC":                     reflect.ValueOf(constant.MakeFromLiteral("83", token.INT, 0)),
		"SYS_FGETXATTR":                     reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"SYS_FINIT_MODULE":                  reflect.ValueOf(constant.MakeFromLiteral("273", token.INT, 0)),
		"SYS_FLISTXATTR":                    reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"SYS_FLOCK":                         reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SYS_FREMOVEXATTR":                  reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SYS_FSCONFIG":                      reflect.ValueOf(constant.MakeFromLiteral("431", token.INT, 0)),
		"SYS_FSETXATTR":                     reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"SYS_FSMOUNT":                       reflect.ValueOf(constant.MakeFromLiteral("432", token.INT, 0)),
		"SYS_FSOPEN":                        reflect.ValueOf(constant.MakeFromLiteral("430", token.INT, 0)),
		"SYS_FSPICK":                        reflect.ValueOf(constant.MakeFromLiteral("433", token.INT, 0)),
		"SYS_FSTATFS":                       reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"SYS_FSYNC":                         reflect.ValueOf(constant.MakeFromLiteral("82", token.INT, 0)),
		"SYS_FTRUNCATE":                     reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"SYS_FUTEX":                         reflect.ValueOf(constant.MakeFromLiteral("98", token.INT, 0)),
		"SYS_FUTEX_WAITV":                   reflect.ValueOf(constant.MakeFromLiteral("449", token.INT, 0)),
		"SYS_GETCPU":                        reflect.ValueOf(constant.MakeFromLiteral("168", token.INT, 0)),
		"SYS_GETCWD":                        reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"SYS_GETDENTS64":                    reflect.ValueOf(constant.MakeFromLiteral("61", token.INT, 0)),
		"SYS_GETEGID":                       reflect.ValueOf(constant.MakeFromLiteral("177", token.INT, 0)),
		"SYS_GETEUID":                       reflect.ValueOf(constant.MakeFromLiteral("175", token.INT, 0)),
		"SYS_GETGID":                        reflect.ValueOf(constant.MakeFromLiteral("176", token.INT, 0)),
		"SYS_GETGROUPS":                     reflect.ValueOf(constant.MakeFromLiteral("158", token.INT, 0)),
		"SYS_GETITIMER":                     reflect.ValueOf(constant.MakeFromLiteral("102", token.INT, 0)),
		"SYS_GETPEERNAME":                   reflect.ValueOf(constant.MakeFromLiteral("205", token.INT, 0)),
		"SYS_GETPGID":                       reflect.ValueOf(constant.MakeFromLiteral("155", token.INT, 0)),
		"SYS_GETPID":                        reflect.ValueOf(constant.MakeFromLiteral("172", token.INT, 0)),
		"SYS_GETPPID":                       reflect.ValueOf(constant.MakeFromLiteral("173", token.INT, 0)),
		"SYS_GETPRIORITY":                   reflect.ValueOf(constant.MakeFromLiteral("141", token.INT, 0)),
		"SYS_GETRANDOM":                     reflect.ValueOf(constant.MakeFromLiteral("278", token.INT, 0)),
		"SYS_GETRESGID":                     reflect.ValueOf(constant.MakeFromLiteral("150", token.INT, 0)),
		"SYS_GETRESUID":                     reflect.ValueOf(constant.MakeFromLiteral("148", token.INT, 0)),
		"SYS_GETRUSAGE":                     reflect.ValueOf(constant.MakeFromLiteral("165", token.INT, 0)),
		"SYS_GETSID":                        reflect.ValueOf(constant.MakeFromLiteral("156", token.INT, 0)),
		"SYS_GETSOCKNAME":                   reflect.ValueOf(constant.MakeFromLiteral("204", token.INT, 0)),
		"SYS_GETSOCKOPT":                    reflect.ValueOf(constant.MakeFromLiteral("209", token.INT, 0)),
		"SYS_GETTID":                        reflect.ValueOf(constant.MakeFromLiteral("178", token.INT, 0)),
		"SYS_GETTIMEOFDAY":                  reflect.ValueOf(constant.MakeFromLiteral("169", token.INT, 0)),
		"SYS_GETUID":                        reflect.ValueOf(constant.MakeFromLiteral("174", token.INT, 0)),
		"SYS_GETXATTR":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SYS_GET_MEMPOLICY":                 reflect.ValueOf(constant.MakeFromLiteral("236", token.INT, 0)),
		"SYS_GET_ROBUST_LIST":               reflect.ValueOf(constant.MakeFromLiteral("100", token.INT, 0)),
		"SYS_INIT_MODULE":                   reflect.ValueOf(constant.MakeFromLiteral("105", token.INT, 0)),
		"SYS_INOTIFY_ADD_WATCH":             reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"SYS_INOTIFY_INIT1":                 reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"SYS_INOTIFY_RM_WATCH":              reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"SYS_IOCTL":                         reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"SYS_IOPRIO_GET":                    reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"SYS_IOPRIO_SET":                    reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"SYS_IO_CANCEL":                     reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"SYS_IO_DESTROY":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SYS_IO_GETEVENTS":                  reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SYS_IO_PGETEVENTS":                 reflect.ValueOf(constant.MakeFromLiteral("292", token.INT, 0)),
		"SYS_IO_SETUP":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"SYS_IO_SUBMIT":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SYS_IO_URING_ENTER":                reflect.ValueOf(constant.MakeFromLiteral("426", token.INT, 0)),
		"SYS_IO_URING_REGISTER":             reflect.ValueOf(constant.MakeFromLiteral("427", token.INT, 0)),
		"SYS_IO_URING_SETUP":                reflect.ValueOf(constant.MakeFromLiteral("425", token.INT, 0)),
		"SYS_KCMP":                          reflect.ValueOf(constant.MakeFromLiteral("272", token.INT, 0)),
		"SYS_KEXEC_FILE_LOAD":               reflect.ValueOf(constant.MakeFromLiteral("294", token.INT, 0)),
		"SYS_KEXEC_LOAD":                    reflect.ValueOf(constant.MakeFromLiteral("104", token.INT, 0)),
		"SYS_KEYCTL":                        reflect.ValueOf(constant.MakeFromLiteral("219", token.INT, 0)),
		"SYS_KILL":                          reflect.ValueOf(constant.MakeFromLiteral("129", token.INT, 0)),
		"SYS_LANDLOCK_ADD_RULE":             reflect.ValueOf(constant.MakeFromLiteral("445", token.INT, 0)),
		"SYS_LANDLOCK_CREATE_RULESET":       reflect.ValueOf(constant.MakeFromLiteral("444", token.INT, 0)),
		"SYS_LANDLOCK_RESTRICT_SELF":        reflect.ValueOf(constant.MakeFromLiteral("446", token.INT, 0)),
		"SYS_LGETXATTR":                     reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"SYS_LINKAT":                        reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"SYS_LISTEN":                        reflect.ValueOf(constant.MakeFromLiteral("201", token.INT, 0)),
		"SYS_LISTXATTR":                     reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"SYS_LLISTXATTR":                    reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"SYS_LOOKUP_DCOOKIE":                reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"SYS_LREMOVEXATTR":                  reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"SYS_LSEEK":                         reflect.ValueOf(constant.MakeFromLiteral("62", token.INT, 0)),
		"SYS_LSETXATTR":                     reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"SYS_MADVISE":                       reflect.ValueOf(constant.MakeFromLiteral("233", token.INT, 0)),
		"SYS_MBIND":                         reflect.ValueOf(constant.MakeFromLiteral("235", token.INT, 0)),
		"SYS_MEMBARRIER":                    reflect.ValueOf(constant.MakeFromLiteral("283", token.INT, 0)),
		"SYS_MEMFD_CREATE":                  reflect.ValueOf(constant.MakeFromLiteral("279", token.INT, 0)),
		"SYS_MIGRATE_PAGES":                 reflect.ValueOf(constant.MakeFromLiteral("238", token.INT, 0)),
		"SYS_MINCORE":                       reflect.ValueOf(constant.MakeFromLiteral("232", token.INT, 0)),
		"SYS_MKDIRAT":                       reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"SYS_MKNODAT":                       reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"SYS_MLOCK":                         reflect.ValueOf(constant.MakeFromLiteral("228", token.INT, 0)),
		"SYS_MLOCK2":                        reflect.ValueOf(constant.MakeFromLiteral("284", token.INT, 0)),
		"SYS_MLOCKALL":                      reflect.ValueOf(constant.MakeFromLiteral("230", token.INT, 0)),
		"SYS_MMAP":                          reflect.ValueOf(constant.MakeFromLiteral("222", token.INT, 0)),
		"SYS_MOUNT":                         reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"SYS_MOUNT_SETATTR":                 reflect.ValueOf(constant.MakeFromLiteral("442", token.INT, 0)),
		"SYS_MOVE_MOUNT":                    reflect.ValueOf(constant.MakeFromLiteral("429", token.INT, 0)),
		"SYS_MOVE_PAGES":                    reflect.ValueOf(constant.MakeFromLiteral("239", token.INT, 0)),
		"SYS_MPROTECT":                      reflect.ValueOf(constant.MakeFromLiteral("226", token.INT, 0)),
		"SYS_MQ_GETSETATTR":                 reflect.ValueOf(constant.MakeFromLiteral("185", token.INT, 0)),
		"SYS_MQ_NOTIFY":                     reflect.ValueOf(constant.MakeFromLiteral("184", token.INT, 0)),
		"SYS_MQ_OPEN":                       reflect.ValueOf(constant.MakeFromLiteral("180", token.INT, 0)),
		"SYS_MQ_TIMEDRECEIVE":               reflect.ValueOf(constant.MakeFromLiteral("183", token.INT, 0)),
		"SYS_MQ_TIMEDSEND":                  reflect.ValueOf(constant.MakeFromLiteral("182", token.INT, 0)),
		"SYS_MQ_UNLINK":                     reflect.ValueOf(constant.MakeFromLiteral("181", token.INT, 0)),
		"SYS_MREMAP":                        reflect.ValueOf(constant.MakeFromLiteral("216", token.INT, 0)),
		"SYS_MSGCTL":                        reflect.ValueOf(constant.MakeFromLiteral("187", token.INT, 0)),
		"SYS_MSGGET":                        reflect.ValueOf(constant.MakeFromLiteral("186", token.INT, 0)),
		"SYS_MSGRCV":                        reflect.ValueOf(constant.MakeFromLiteral("188", token.INT, 0)),
		"SYS_MSGSND":                        reflect.ValueOf(constant.MakeFromLiteral("189", token.INT, 0)),
		"SYS_MSYNC":                         reflect.ValueOf(constant.MakeFromLiteral("227", token.INT, 0)),
		"SYS_MUNLOCK":                       reflect.ValueOf(constant.MakeFromLiteral("229", token.INT, 0)),
		"SYS_MUNLOCKALL":                    reflect.ValueOf(constant.MakeFromLiteral("231", token.INT, 0)),
		"SYS_MUNMAP":                        reflect.ValueOf(constant.MakeFromLiteral("215", token.INT, 0)),
		"SYS_NAME_TO_HANDLE_AT":             reflect.ValueOf(constant.MakeFromLiteral("264", token.INT, 0)),
		"SYS_NANOSLEEP":                     reflect.ValueOf(constant.MakeFromLiteral("101", token.INT, 0)),
		"SYS_NFSSERVCTL":                    reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"SYS_OPENAT":                        reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"SYS_OPENAT2":                       reflect.ValueOf(constant.MakeFromLiteral("437", token.INT, 0)),
		"SYS_OPEN_BY_HANDLE_AT":             reflect.ValueOf(constant.MakeFromLiteral("265", token.INT, 0)),
		"SYS_OPEN_TREE":                     reflect.ValueOf(constant.MakeFromLiteral("428", token.INT, 0)),
		"SYS_PERF_EVENT_OPEN":               reflect.ValueOf(constant.MakeFromLiteral("241", token.INT, 0)),
		"SYS_PERSONALITY":                   reflect.ValueOf(constant.MakeFromLiteral("92", token.INT, 0)),
		"SYS_PIDFD_GETFD":                   reflect.ValueOf(constant.MakeFromLiteral("438", token.INT, 0)),
		"SYS_PIDFD_OPEN":                    reflect.ValueOf(constant.MakeFromLiteral("434", token.INT, 0)),
		"SYS_PIDFD_SEND_SIGNAL":             reflect.ValueOf(constant.MakeFromLiteral("424", token.INT, 0)),
		"SYS_PIPE2":                         reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"SYS_PIVOT_ROOT":                    reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"SYS_PKEY_ALLOC":                    reflect.ValueOf(constant.MakeFromLiteral("289", token.INT, 0)),
		"SYS_PKEY_FREE":                     reflect.ValueOf(constant.MakeFromLiteral("290", token.INT, 0)),
		"SYS_PKEY_MPROTECT":                 reflect.ValueOf(constant.MakeFromLiteral("288", token.INT, 0)),
		"SYS_PPOLL":                         reflect.ValueOf(constant.MakeFromLiteral("73", token.INT, 0)),
		"SYS_PRCTL":                         reflect.ValueOf(constant.MakeFromLiteral("167", token.INT, 0)),
		"SYS_PREAD64":                       reflect.ValueOf(constant.MakeFromLiteral("67", token.INT, 0)),
		"SYS_PREADV":                        reflect.ValueOf(constant.MakeFromLiteral("69", token.INT, 0)),
		"SYS_PREADV2":                       reflect.ValueOf(constant.MakeFromLiteral("286", token.INT, 0)),
		"SYS_PRLIMIT64":                     reflect.ValueOf(constant.MakeFromLiteral("261", token.INT, 0)),
		"SYS_PROCESS_MADVISE":               reflect.ValueOf(constant.MakeFromLiteral("440", token.INT, 0)),
		"SYS_PROCESS_MRELEASE":              reflect.ValueOf(constant.MakeFromLiteral("448", token.INT, 0)),
		"SYS_PROCESS_VM_READV":              reflect.ValueOf(constant.MakeFromLiteral("270", token.INT, 0)),
		"SYS_PROCESS_VM_WRITEV":             reflect.ValueOf(constant.MakeFromLiteral("271", token.INT, 0)),
		"SYS_PSELECT6":                      reflect.ValueOf(constant.MakeFromLiteral("72", token.INT, 0)),
		"SYS_PTRACE":                        reflect.ValueOf(constant.MakeFromLiteral("117", token.INT, 0)),
		"SYS_PWRITE64":                      reflect.ValueOf(constant.MakeFromLiteral("68", token.INT, 0)),
		"SYS_PWRITEV":                       reflect.ValueOf(constant.MakeFromLiteral("70", token.INT, 0)),
		"SYS_PWRITEV2":                      reflect.ValueOf(constant.MakeFromLiteral("287", token.INT, 0)),
		"SYS_QUOTACTL":                      reflect.ValueOf(constant.MakeFromLiteral("60", token.INT, 0)),
		"SYS_QUOTACTL_FD":                   reflect.ValueOf(constant.MakeFromLiteral("443", token.INT, 0)),
		"SYS_READ":                          reflect.ValueOf(constant.MakeFromLiteral("63", token.INT, 0)),
		"SYS_READAHEAD":                     reflect.ValueOf(constant.MakeFromLiteral("213", token.INT, 0)),
		"SYS_READLINKAT":                    reflect.ValueOf(constant.MakeFromLiteral("78", token.INT, 0)),
		"SYS_READV":                         reflect.ValueOf(constant.MakeFromLiteral("65", token.INT, 0)),
		"SYS_REBOOT":                        reflect.ValueOf(constant.MakeFromLiteral("142", token.INT, 0)),
		"SYS_RECVFROM":                      reflect.ValueOf(constant.MakeFromLiteral("207", token.INT, 0)),
		"SYS_RECVMMSG":                      reflect.ValueOf(constant.MakeFromLiteral("243", token.INT, 0)),
		"SYS_RECVMSG":                       reflect.ValueOf(constant.MakeFromLiteral("212", token.INT, 0)),
		"SYS_REMAP_FILE_PAGES":              reflect.ValueOf(constant.MakeFromLiteral("234", token.INT, 0)),
		"SYS_REMOVEXATTR":                   reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"SYS_RENAMEAT2":                     reflect.ValueOf(constant.MakeFromLiteral("276", token.INT, 0)),
		"SYS_REQUEST_KEY":                   reflect.ValueOf(constant.MakeFromLiteral("218", token.INT, 0)),
		"SYS_RESTART_SYSCALL":               reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"SYS_RSEQ":                          reflect.ValueOf(constant.MakeFromLiteral("293", token.INT, 0)),
		"SYS_RT_SIGACTION":                  reflect.ValueOf(constant.MakeFromLiteral("134", token.INT, 0)),
		"SYS_RT_SIGPENDING":                 reflect.ValueOf(constant.MakeFromLiteral("136", token.INT, 0)),
		"SYS_RT_SIGPROCMASK":                reflect.ValueOf(constant.MakeFromLiteral("135", token.INT, 0)),
		"SYS_RT_SIGQUEUEINFO":               reflect.ValueOf(constant.MakeFromLiteral("138", token.INT, 0)),
		"SYS_RT_SIGRETURN":                  reflect.ValueOf(constant.MakeFromLiteral("139", token.INT, 0)),
		"SYS_RT_SIGSUSPEND":                 reflect.ValueOf(constant.MakeFromLiteral("133", token.INT, 0)),
		"SYS_RT_SIGTIMEDWAIT":               reflect.ValueOf(constant.MakeFromLiteral("137", token.INT, 0)),
		"SYS_RT_TGSIGQUEUEINFO":             reflect.ValueOf(constant.MakeFromLiteral("240", token.INT, 0)),
		"SYS_SCHED_GETAFFINITY":             reflect.ValueOf(constant.MakeFromLiteral("123", token.INT, 0)),
		"SYS_SCHED_GETATTR":                 reflect.ValueOf(constant.MakeFromLiteral("275", token.INT, 0)),
		"SYS_SCHED_GETPARAM":                reflect.ValueOf(constant.MakeFromLiteral("121", token.INT, 0)),
		"SYS_SCHED_GETSCHEDULER":            reflect.ValueOf(constant.MakeFromLiteral("120", token.INT, 0)),
		"SYS_SCHED_GET_PRIORITY_MAX":        reflect.ValueOf(constant.MakeFromLiteral("125", token.INT, 0)),
		"SYS_SCHED_GET_PRIORITY_MIN":        reflect.ValueOf(constant.MakeFromLiteral("126", token.INT, 0)),
		"SYS_SCHED_RR_GET_INTERVAL":         reflect.ValueOf(constant.MakeFromLiteral("127", token.INT, 0)),
		"SYS_SCHED_SETAFFINITY":             reflect.ValueOf(constant.MakeFromLiteral("122", token.INT, 0)),
		"SYS_SCHED_SETATTR":                 reflect.ValueOf(constant.MakeFromLiteral("274", token.INT, 0)),
		"SYS_SCHED_SETPARAM":                reflect.ValueOf(constant.MakeFromLiteral("118", token.INT, 0)),
		"SYS_SCHED_SETSCHEDULER":            reflect.ValueOf(constant.MakeFromLiteral("119", token.INT, 0)),
		"SYS_SCHED_YIELD":                   reflect.ValueOf(constant.MakeFromLiteral("124", token.INT, 0)),
		"SYS_SECCOMP":                       reflect.ValueOf(constant.MakeFromLiteral("277", token.INT, 0)),
		"SYS_SEMCTL":                        reflect.ValueOf(constant.MakeFromLiteral("191", token.INT, 0)),
		"SYS_SEMGET":                        reflect.ValueOf(constant.MakeFromLiteral("190", token.INT, 0)),
		"SYS_SEMOP":                         reflect.ValueOf(constant.MakeFromLiteral("193", token.INT, 0)),
		"SYS_SEMTIMEDOP":                    reflect.ValueOf(constant.MakeFromLiteral("192", token.INT, 0)),
		"SYS_SENDFILE":                      reflect.ValueOf(constant.MakeFromLiteral("71", token.INT, 0)),
		"SYS_SENDMMSG":                      reflect.ValueOf(constant.MakeFromLiteral("269", token.INT, 0)),
		"SYS_SENDMSG":                       reflect.ValueOf(constant.MakeFromLiteral("211", token.INT, 0)),
		"SYS_SENDTO":                        reflect.ValueOf(constant.MakeFromLiteral("206", token.INT, 0)),
		"SYS_SETDOMAINNAME":                 reflect.ValueOf(constant.MakeFromLiteral("162", token.INT, 0)),
		"SYS_SETFSGID":                      reflect.ValueOf(constant.MakeFromLiteral("152", token.INT, 0)),
		"SYS_SETFSUID":                      reflect.ValueOf(constant.MakeFromLiteral("151", token.INT, 0)),
		"SYS_SETGID":                        reflect.ValueOf(constant.MakeFromLiteral("144", token.INT, 0)),
		"SYS_SETGROUPS":                     reflect.ValueOf(constant.MakeFromLiteral("159", token.INT, 0)),
		"SYS_SETHOSTNAME":                   reflect.ValueOf(constant.MakeFromLiteral("161", token.INT, 0)),
		"SYS_SETITIMER":                     reflect.ValueOf(constant.MakeFromLiteral("103", token.INT, 0)),
		"SYS_SETNS":                         reflect.ValueOf(constant.MakeFromLiteral("268", token.INT, 0)),
		"SYS_SETPGID":                       reflect.ValueOf(constant.MakeFromLiteral("154", token.INT, 0)),
		"SYS_SETPRIORITY":                   reflect.ValueOf(constant.MakeFromLiteral("140", token.INT, 0)),
		"SYS_SETREGID":                      reflect.ValueOf(constant.MakeFromLiteral("143", token.INT, 0)),
		"SYS_SETRESGID":                     reflect.ValueOf(constant.MakeFromLiteral("149", token.INT, 0)),
		"SYS_SETRESUID":                     reflect.ValueOf(constant.MakeFromLiteral("147", token.INT, 0)),
		"SYS_SETREUID":                      reflect.ValueOf(constant.MakeFromLiteral("145", token.INT, 0)),
		"SYS_SETSID":                        reflect.ValueOf(constant.MakeFromLiteral("157", token.INT, 0)),
		"SYS_SETSOCKOPT":                    reflect.ValueOf(constant.MakeFromLiteral("208", token.INT, 0)),
		"SYS_SETTIMEOFDAY":                  reflect.ValueOf(constant.MakeFromLiteral("170", token.INT, 0)),
		"SYS_SETUID":                        reflect.ValueOf(constant.MakeFromLiteral("146", token.INT, 0)),
		"SYS_SETXATTR":                      reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"SYS_SET_MEMPOLICY":                 reflect.ValueOf(constant.MakeFromLiteral("237", token.INT, 0)),
		"SYS_SET_MEMPOLICY_HOME_NODE":       reflect.ValueOf(constant.MakeFromLiteral("450", token.INT, 0)),
		"SYS_SET_ROBUST_LIST":               reflect.ValueOf(constant.MakeFromLiteral("99", token.INT, 0)),
		"SYS_SET_TID_ADDRESS":               reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"SYS_SHMAT":                         reflect.ValueOf(constant.MakeFromLiteral("196", token.INT, 0)),
		"SYS_SHMCTL":                        reflect.ValueOf(constant.MakeFromLiteral("195", token.INT, 0)),
		"SYS_SHMDT":                         reflect.ValueOf(constant.MakeFromLiteral("197", token.INT, 0)),
		"SYS_SHMGET":                        reflect.ValueOf(constant.MakeFromLiteral("194", token.INT, 0)),
		"SYS_SHUTDOWN":                      reflect.ValueOf(constant.MakeFromLiteral("210", token.INT, 0)),
		"SYS_SIGALTSTACK":                   reflect.ValueOf(constant.MakeFromLiteral("132", token.INT, 0)),
		"SYS_SIGNALFD4":                     reflect.ValueOf(constant.MakeFromLiteral("74", token.INT, 0)),
		"SYS_SOCKET":                        reflect.ValueOf(constant.MakeFromLiteral("198", token.INT, 0)),
		"SYS_SOCKETPAIR":                    reflect.ValueOf(constant.MakeFromLiteral("199", token.INT, 0)),
		"SYS_SPLICE":                        reflect.ValueOf(constant.MakeFromLiteral("76", token.INT, 0)),
		"SYS_STATFS":                        reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"SYS_STATX":                         reflect.ValueOf(constant.MakeFromLiteral("291", token.INT, 0)),
		"SYS_SWAPOFF":                       reflect.ValueOf(constant.MakeFromLiteral("225", token.INT, 0)),
		"SYS_SWAPON":                        reflect.ValueOf(constant.MakeFromLiteral("224", token.INT, 0)),
		"SYS_SYMLINKAT":                     reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"SYS_SYNC":                          reflect.ValueOf(constant.MakeFromLiteral("81", token.INT, 0)),
		"SYS_SYNCFS":                        reflect.ValueOf(constant.MakeFromLiteral("267", token.INT, 0)),
		"SYS_SYNC_FILE_RANGE":               reflect.ValueOf(constant.MakeFromLiteral("84", token.INT, 0)),
		"SYS_SYSINFO":                       reflect.ValueOf(constant.MakeFromLiteral("179", token.INT, 0)),
		"SYS_SYSLOG":                        reflect.ValueOf(constant.MakeFromLiteral("116", token.INT, 0)),
		"SYS_TEE":                           reflect.ValueOf(constant.MakeFromLiteral("77", token.INT, 0)),
		"SYS_TGKILL":                        reflect.ValueOf(constant.MakeFromLiteral("131", token.INT, 0)),
		"SYS_TIMERFD_CREATE":                reflect.ValueOf(constant.MakeFromLiteral("85", token.INT, 0)),
		"SYS_TIMERFD_GETTIME":               reflect.ValueOf(constant.MakeFromLiteral("87", token.INT, 0)),
		"SYS_TIMERFD_SETTIME":               reflect.ValueOf(constant.MakeFromLiteral("86", token.INT, 0)),
		"SYS_TIMER_CREATE":                  reflect.ValueOf(constant.MakeFromLiteral("107", token.INT, 0)),
		"SYS_TIMER_DELETE":                  reflect.ValueOf(constant.MakeFromLiteral("111", token.INT, 0)),
		"SYS_TIMER_GETOVERRUN":              reflect.ValueOf(constant.MakeFromLiteral("109", token.INT, 0)),
		"SYS_TIMER_GETTIME":                 reflect.ValueOf(constant.MakeFromLiteral("108", token.INT, 0)),
		"SYS_TIMER_SETTIME":                 reflect.ValueOf(constant.MakeFromLiteral("110", token.INT, 0)),
		"SYS_TIMES":                         reflect.ValueOf(constant.MakeFromLiteral("153", token.INT, 0)),
		"SYS_TKILL":                         reflect.ValueOf(constant.MakeFromLiteral("130", token.INT, 0)),
		"SYS_TRUNCATE":                      reflect.ValueOf(constant.MakeFromLiteral("45", token.INT, 0)),
		"SYS_UMASK":                         reflect.ValueOf(constant.MakeFromLiteral("166", token.INT, 0)),
		"SYS_UMOUNT2":                       reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"SYS_UNAME":                         reflect.ValueOf(constant.MakeFromLiteral("160", token.INT, 0)),
		"SYS_UNLINKAT":                      reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"SYS_UNSHARE":                       reflect.ValueOf(constant.MakeFromLiteral("97", token.INT, 0)),
		"SYS_USERFAULTFD":                   reflect.ValueOf(constant.MakeFromLiteral("282", token.INT, 0)),
		"SYS_UTIMENSAT":                     reflect.ValueOf(constant.MakeFromLiteral("88", token.INT, 0)),
		"SYS_VHANGUP":                       reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"SYS_VMSPLICE":                      reflect.ValueOf(constant.MakeFromLiteral("75", token.INT, 0)),
		"SYS_WAIT4":                         reflect.ValueOf(constant.MakeFromLiteral("260", token.INT, 0)),
		"SYS_WAITID":                        reflect.ValueOf(constant.MakeFromLiteral("95", token.INT, 0)),
		"SYS_WRITE":                         reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"SYS_WRITEV":                        reflect.ValueOf(constant.MakeFromLiteral("66", token.INT, 0)),
		"S_BLKSIZE":                         reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"S_IEXEC":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"S_IFBLK":                           reflect.ValueOf(constant.MakeFromLiteral("24576", token.INT, 0)),
		"S_IFCHR":                           reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"S_IFDIR":                           reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"S_IFIFO":                           reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"S_IFLNK":                           reflect.ValueOf(constant.MakeFromLiteral("40960", token.INT, 0)),
		"S_IFMT":                            reflect.ValueOf(constant.MakeFromLiteral("61440", token.INT, 0)),
		"S_IFREG":                           reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"S_IFSOCK":                          reflect.ValueOf(constant.MakeFromLiteral("49152", token.INT, 0)),
		"S_IREAD":                           reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"S_IRGRP":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"S_IROTH":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"S_IRUSR":                           reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"S_IRWXG":                           reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"S_IRWXO":                           reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"S_IRWXU":                           reflect.ValueOf(constant.MakeFromLiteral("448", token.INT, 0)),
		"S_ISGID":                           reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"S_ISUID":                           reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"S_ISVTX":                           reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"S_IWGRP":                           reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"S_IWOTH":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"S_IWRITE":                          reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"S_IWUSR":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"S_IXGRP":                           reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"S_IXOTH":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"S_IXUSR":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"Seek":                              reflect.ValueOf(syscall.Seek),
		"Select":                            reflect.ValueOf(syscall.Select),
		"Sendfile":                          reflect.ValueOf(syscall.Sendfile),
		"Sendmsg":                           reflect.ValueOf(syscall.Sendmsg),
		"SendmsgN":                          reflect.ValueOf(syscall.SendmsgN),
		"Sendto":                            reflect.ValueOf(syscall.Sendto),
		"SetLsfPromisc":                     reflect.ValueOf(syscall.SetLsfPromisc),
		"SetNonblock":                       reflect.ValueOf(syscall.SetNonblock),
		"Setdomainname":                     reflect.ValueOf(syscall.Setdomainname),
		"Setegid":                           reflect.ValueOf(syscall.Setegid),
		"Setenv":                            reflect.ValueOf(syscall.Setenv),
		"Seteuid":                           reflect.ValueOf(syscall.Seteuid),
		"Setfsgid":                          reflect.ValueOf(syscall.Setfsgid),
		"Setfsuid":                          reflect.ValueOf(syscall.Setfsuid),
		"Setgid":                            reflect.ValueOf(syscall.Setgid),
		"Setgroups":                         reflect.ValueOf(syscall.Setgroups),
		"Sethostname":                       reflect.ValueOf(syscall.Sethostname),
		"Setpgid":                           reflect.ValueOf(syscall.Setpgid),
		"Setpriority":                       reflect.ValueOf(syscall.Setpriority),
		"Setregid":                          reflect.ValueOf(syscall.Setregid),
		"Setresgid":                         reflect.ValueOf(syscall.Setresgid),
		"Setresuid":                         reflect.ValueOf(syscall.Setresuid),
		"Setreuid":                          reflect.ValueOf(syscall.Setreuid),
		"Setrlimit":                         reflect.ValueOf(syscall.Setrlimit),
		"Setsid":                            reflect.ValueOf(syscall.Setsid),
		"SetsockoptByte":                    reflect.ValueOf(syscall.SetsockoptByte),
		"SetsockoptICMPv6Filter":            reflect.ValueOf(syscall.SetsockoptICMPv6Filter),
		"SetsockoptIPMreq":                  reflect.ValueOf(syscall.SetsockoptIPMreq),
		"SetsockoptIPMreqn":                 reflect.ValueOf(syscall.SetsockoptIPMreqn),
		"SetsockoptIPv6Mreq":                reflect.ValueOf(syscall.SetsockoptIPv6Mreq),
		"SetsockoptInet4Addr":               reflect.ValueOf(syscall.SetsockoptInet4Addr),
		"SetsockoptInt":                     reflect.ValueOf(syscall.SetsockoptInt),
		"SetsockoptLinger":                  reflect.ValueOf(syscall.SetsockoptLinger),
		"SetsockoptString":                  reflect.ValueOf(syscall.SetsockoptString),
		"SetsockoptTimeval":                 reflect.ValueOf(syscall.SetsockoptTimeval),
		"Settimeofday":                      reflect.ValueOf(syscall.Settimeofday),
		"Setuid":                            reflect.ValueOf(syscall.Setuid),
		"Setxattr":                          reflect.ValueOf(syscall.Setxattr),
		"SizeofCmsghdr":                     reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SizeofICMPv6Filter":                reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SizeofIPMreq":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofIPMreqn":                     reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"SizeofIPv6MTUInfo":                 reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SizeofIPv6Mreq":                    reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SizeofIfAddrmsg":                   reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofIfInfomsg":                   reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SizeofInet4Pktinfo":                reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"SizeofInet6Pktinfo":                reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SizeofInotifyEvent":                reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SizeofLinger":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofMsghdr":                      reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"SizeofNlAttr":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SizeofNlMsgerr":                    reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SizeofNlMsghdr":                    reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SizeofRtAttr":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SizeofRtGenmsg":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SizeofRtMsg":                       reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"SizeofRtNexthop":                   reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofSockFilter":                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofSockFprog":                   reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SizeofSockaddrAny":                 reflect.ValueOf(constant.MakeFromLiteral("112", token.INT, 0)),
		"SizeofSockaddrInet4":               reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SizeofSockaddrInet6":               reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"SizeofSockaddrLinklayer":           reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SizeofSockaddrNetlink":             reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"SizeofSockaddrUnix":                reflect.ValueOf(constant.MakeFromLiteral("110", token.INT, 0)),
		"SizeofTCPInfo":                     reflect.ValueOf(constant.MakeFromLiteral("104", token.INT, 0)),
		"SizeofUcred":                       reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"SlicePtrFromStrings":               reflect.ValueOf(syscall.SlicePtrFromStrings),
		"Socket":                            reflect.ValueOf(syscall.Socket),
		"SocketDisableIPv6":                 reflect.ValueOf(&syscall.SocketDisableIPv6).Elem(),
		"Socketpair":                        reflect.ValueOf(syscall.Socketpair),
		"Splice":                            reflect.ValueOf(syscall.Splice),
		"Stat":                              reflect.ValueOf(syscall.Stat),
		"Statfs":                            reflect.ValueOf(syscall.Statfs),
		"Stderr":                            reflect.ValueOf(&syscall.Stderr).Elem(),
		"Stdin":                             reflect.ValueOf(&syscall.Stdin).Elem(),
		"Stdout":                            reflect.ValueOf(&syscall.Stdout).Elem(),
		"StringBytePtr":                     reflect.ValueOf(syscall.StringBytePtr),
		"StringByteSlice":                   reflect.ValueOf(syscall.StringByteSlice),
		"StringSlicePtr":                    reflect.ValueOf(syscall.StringSlicePtr),
		"Symlink":                           reflect.ValueOf(syscall.Symlink),
		"Sync":                              reflect.ValueOf(syscall.Sync),
		"SyncFileRange":                     reflect.ValueOf(syscall.SyncFileRange),
		"Sysinfo":                           reflect.ValueOf(syscall.Sysinfo),
		"TCFLSH":                            reflect.ValueOf(constant.MakeFromLiteral("21515", token.INT, 0)),
		"TCGETS":                            reflect.ValueOf(constant.MakeFromLiteral("21505", token.INT, 0)),
		"TCIFLUSH":                          reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"TCIOFLUSH":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TCOFLUSH":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TCP_CC_INFO":                       reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"TCP_CM_INQ":                        reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"TCP_CONGESTION":                    reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"TCP_COOKIE_IN_ALWAYS":              reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TCP_COOKIE_MAX":                    reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TCP_COOKIE_MIN":                    reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TCP_COOKIE_OUT_NEVER":              reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TCP_COOKIE_PAIR_SIZE":              reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"TCP_COOKIE_TRANSACTIONS":           reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"TCP_CORK":                          reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"TCP_DEFER_ACCEPT":                  reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"TCP_FASTOPEN":                      reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"TCP_FASTOPEN_CONNECT":              reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"TCP_FASTOPEN_KEY":                  reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"TCP_FASTOPEN_NO_COOKIE":            reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"TCP_INFO":                          reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"TCP_INQ":                           reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"TCP_KEEPCNT":                       reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"TCP_KEEPIDLE":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TCP_KEEPINTVL":                     reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"TCP_LINGER2":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TCP_MAXSEG":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TCP_MAXWIN":                        reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"TCP_MAX_WINSHIFT":                  reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"TCP_MD5SIG":                        reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"TCP_MD5SIG_EXT":                    reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"TCP_MD5SIG_FLAG_PREFIX":            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TCP_MD5SIG_MAXKEYLEN":              reflect.ValueOf(constant.MakeFromLiteral("80", token.INT, 0)),
		"TCP_MSS":                           reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"TCP_MSS_DEFAULT":                   reflect.ValueOf(constant.MakeFromLiteral("536", token.INT, 0)),
		"TCP_MSS_DESIRED":                   reflect.ValueOf(constant.MakeFromLiteral("1220", token.INT, 0)),
		"TCP_NODELAY":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TCP_NOTSENT_LOWAT":                 reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"TCP_QUEUE_SEQ":                     reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"TCP_QUICKACK":                      reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"TCP_REPAIR":                        reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"TCP_REPAIR_OFF":                    reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"TCP_REPAIR_OFF_NO_WP":              reflect.ValueOf(constant.MakeFromLiteral("-1", token.INT, 0)),
		"TCP_REPAIR_ON":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TCP_REPAIR_OPTIONS":                reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"TCP_REPAIR_QUEUE":                  reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"TCP_REPAIR_WINDOW":                 reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"TCP_SAVED_SYN":                     reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"TCP_SAVE_SYN":                      reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"TCP_SYNCNT":                        reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"TCP_S_DATA_IN":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TCP_S_DATA_OUT":                    reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TCP_THIN_DUPACK":                   reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"TCP_THIN_LINEAR_TIMEOUTS":          reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TCP_TIMESTAMP":                     reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"TCP_TX_DELAY":                      reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"TCP_ULP":                           reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"TCP_USER_TIMEOUT":                  reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"TCP_WINDOW_CLAMP":                  reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"TCP_ZEROCOPY_RECEIVE":              reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"TCSAFLUSH":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TCSETS":                            reflect.ValueOf(constant.MakeFromLiteral("21506", token.INT, 0)),
		"TIOCCBRK":                          reflect.ValueOf(constant.MakeFromLiteral("21544", token.INT, 0)),
		"TIOCCONS":                          reflect.ValueOf(constant.MakeFromLiteral("21533", token.INT, 0)),
		"TIOCEXCL":                          reflect.ValueOf(constant.MakeFromLiteral("21516", token.INT, 0)),
		"TIOCGDEV":                          reflect.ValueOf(constant.MakeFromLiteral("2147767346", token.INT, 0)),
		"TIOCGETD":                          reflect.ValueOf(constant.MakeFromLiteral("21540", token.INT, 0)),
		"TIOCGEXCL":                         reflect.ValueOf(constant.MakeFromLiteral("2147767360", token.INT, 0)),
		"TIOCGICOUNT":                       reflect.ValueOf(constant.MakeFromLiteral("21597", token.INT, 0)),
		"TIOCGISO7816":                      reflect.ValueOf(constant.MakeFromLiteral("2150126658", token.INT, 0)),
		"TIOCGLCKTRMIOS":                    reflect.ValueOf(constant.MakeFromLiteral("21590", token.INT, 0)),
		"TIOCGPGRP":                         reflect.ValueOf(constant.MakeFromLiteral("21519", token.INT, 0)),
		"TIOCGPKT":                          reflect.ValueOf(constant.MakeFromLiteral("2147767352", token.INT, 0)),
		"TIOCGPTLCK":                        reflect.ValueOf(constant.MakeFromLiteral("2147767353", token.INT, 0)),
		"TIOCGPTN":                          reflect.ValueOf(constant.MakeFromLiteral("2147767344", token.INT, 0)),
		"TIOCGPTPEER":                       reflect.ValueOf(constant.MakeFromLiteral("21569", token.INT, 0)),
		"TIOCGRS485":                        reflect.ValueOf(constant.MakeFromLiteral("21550", token.INT, 0)),
		"TIOCGSERIAL":                       reflect.ValueOf(constant.MakeFromLiteral("21534", token.INT, 0)),
		"TIOCGSID":                          reflect.ValueOf(constant.MakeFromLiteral("21545", token.INT, 0)),
		"TIOCGSOFTCAR":                      reflect.ValueOf(constant.MakeFromLiteral("21529", token.INT, 0)),
		"TIOCGWINSZ":                        reflect.ValueOf(constant.MakeFromLiteral("21523", token.INT, 0)),
		"TIOCINQ":                           reflect.ValueOf(constant.MakeFromLiteral("21531", token.INT, 0)),
		"TIOCLINUX":                         reflect.ValueOf(constant.MakeFromLiteral("21532", token.INT, 0)),
		"TIOCMBIC":                          reflect.ValueOf(constant.MakeFromLiteral("21527", token.INT, 0)),
		"TIOCMBIS":                          reflect.ValueOf(constant.MakeFromLiteral("21526", token.INT, 0)),
		"TIOCMGET":                          reflect.ValueOf(constant.MakeFromLiteral("21525", token.INT, 0)),
		"TIOCMIWAIT":                        reflect.ValueOf(constant.MakeFromLiteral("21596", token.INT, 0)),
		"TIOCMSET":                          reflect.ValueOf(constant.MakeFromLiteral("21528", token.INT, 0)),
		"TIOCM_CAR":                         reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"TIOCM_CD":                          reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"TIOCM_CTS":                         reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"TIOCM_DSR":                         reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"TIOCM_DTR":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TIOCM_LE":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TIOCM_RI":                          reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"TIOCM_RNG":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"TIOCM_RTS":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TIOCM_SR":                          reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TIOCM_ST":                          reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TIOCNOTTY":                         reflect.ValueOf(constant.MakeFromLiteral("21538", token.INT, 0)),
		"TIOCNXCL":                          reflect.ValueOf(constant.MakeFromLiteral("21517", token.INT, 0)),
		"TIOCOUTQ":                          reflect.ValueOf(constant.MakeFromLiteral("21521", token.INT, 0)),
		"TIOCPKT":                           reflect.ValueOf(constant.MakeFromLiteral("21536", token.INT, 0)),
		"TIOCPKT_DATA":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"TIOCPKT_DOSTOP":                    reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"TIOCPKT_FLUSHREAD":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TIOCPKT_FLUSHWRITE":                reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TIOCPKT_IOCTL":                     reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"TIOCPKT_NOSTOP":                    reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TIOCPKT_START":                     reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TIOCPKT_STOP":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TIOCSBRK":                          reflect.ValueOf(constant.MakeFromLiteral("21543", token.INT, 0)),
		"TIOCSCTTY":                         reflect.ValueOf(constant.MakeFromLiteral("21518", token.INT, 0)),
		"TIOCSERCONFIG":                     reflect.ValueOf(constant.MakeFromLiteral("21587", token.INT, 0)),
		"TIOCSERGETLSR":                     reflect.ValueOf(constant.MakeFromLiteral("21593", token.INT, 0)),
		"TIOCSERGETMULTI":                   reflect.ValueOf(constant.MakeFromLiteral("21594", token.INT, 0)),
		"TIOCSERGSTRUCT":                    reflect.ValueOf(constant.MakeFromLiteral("21592", token.INT, 0)),
		"TIOCSERGWILD":                      reflect.ValueOf(constant.MakeFromLiteral("21588", token.INT, 0)),
		"TIOCSERSETMULTI":                   reflect.ValueOf(constant.MakeFromLiteral("21595", token.INT, 0)),
		"TIOCSERSWILD":                      reflect.ValueOf(constant.MakeFromLiteral("21589", token.INT, 0)),
		"TIOCSER_TEMT":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TIOCSETD":                          reflect.ValueOf(constant.MakeFromLiteral("21539", token.INT, 0)),
		"TIOCSIG":                           reflect.ValueOf(constant.MakeFromLiteral("1074025526", token.INT, 0)),
		"TIOCSISO7816":                      reflect.ValueOf(constant.MakeFromLiteral("3223868483", token.INT, 0)),
		"TIOCSLCKTRMIOS":                    reflect.ValueOf(constant.MakeFromLiteral("21591", token.INT, 0)),
		"TIOCSPGRP":                         reflect.ValueOf(constant.MakeFromLiteral("21520", token.INT, 0)),
		"TIOCSPTLCK":                        reflect.ValueOf(constant.MakeFromLiteral("1074025521", token.INT, 0)),
		"TIOCSRS485":                        reflect.ValueOf(constant.MakeFromLiteral("21551", token.INT, 0)),
		"TIOCSSERIAL":                       reflect.ValueOf(constant.MakeFromLiteral("21535", token.INT, 0)),
		"TIOCSSOFTCAR":                      reflect.ValueOf(constant.MakeFromLiteral("21530", token.INT, 0)),
		"TIOCSTI":                           reflect.ValueOf(constant.MakeFromLiteral("21522", token.INT, 0)),
		"TIOCSWINSZ":                        reflect.ValueOf(constant.MakeFromLiteral("21524", token.INT, 0)),
		"TIOCVHANGUP":                       reflect.ValueOf(constant.MakeFromLiteral("21559", token.INT, 0)),
		"TOSTOP":                            reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"TUNATTACHFILTER":                   reflect.ValueOf(constant.MakeFromLiteral("1074812117", token.INT, 0)),
		"TUNDETACHFILTER":                   reflect.ValueOf(constant.MakeFromLiteral("1074812118", token.INT, 0)),
		"TUNGETDEVNETNS":                    reflect.ValueOf(constant.MakeFromLiteral("21731", token.INT, 0)),
		"TUNGETFEATURES":                    reflect.ValueOf(constant.MakeFromLiteral("2147767503", token.INT, 0)),
		"TUNGETFILTER":                      reflect.ValueOf(constant.MakeFromLiteral("2148553947", token.INT, 0)),
		"TUNGETIFF":                         reflect.ValueOf(constant.MakeFromLiteral("2147767506", token.INT, 0)),
		"TUNGETSNDBUF":                      reflect.ValueOf(constant.MakeFromLiteral("2147767507", token.INT, 0)),
		"TUNGETVNETBE":                      reflect.ValueOf(constant.MakeFromLiteral("2147767519", token.INT, 0)),
		"TUNGETVNETHDRSZ":                   reflect.ValueOf(constant.MakeFromLiteral("2147767511", token.INT, 0)),
		"TUNGETVNETLE":                      reflect.ValueOf(constant.MakeFromLiteral("2147767517", token.INT, 0)),
		"TUNSETCARRIER":                     reflect.ValueOf(constant.MakeFromLiteral("1074025698", token.INT, 0)),
		"TUNSETDEBUG":                       reflect.ValueOf(constant.MakeFromLiteral("1074025673", token.INT, 0)),
		"TUNSETFILTEREBPF":                  reflect.ValueOf(constant.MakeFromLiteral("2147767521", token.INT, 0)),
		"TUNSETGROUP":                       reflect.ValueOf(constant.MakeFromLiteral("1074025678", token.INT, 0)),
		"TUNSETIFF":                         reflect.ValueOf(constant.MakeFromLiteral("1074025674", token.INT, 0)),
		"TUNSETIFINDEX":                     reflect.ValueOf(constant.MakeFromLiteral("1074025690", token.INT, 0)),
		"TUNSETLINK":                        reflect.ValueOf(constant.MakeFromLiteral("1074025677", token.INT, 0)),
		"TUNSETNOCSUM":                      reflect.ValueOf(constant.MakeFromLiteral("1074025672", token.INT, 0)),
		"TUNSETOFFLOAD":                     reflect.ValueOf(constant.MakeFromLiteral("1074025680", token.INT, 0)),
		"TUNSETOWNER":                       reflect.ValueOf(constant.MakeFromLiteral("1074025676", token.INT, 0)),
		"TUNSETPERSIST":                     reflect.ValueOf(constant.MakeFromLiteral("1074025675", token.INT, 0)),
		"TUNSETQUEUE":                       reflect.ValueOf(constant.MakeFromLiteral("1074025689", token.INT, 0)),
		"TUNSETSNDBUF":                      reflect.ValueOf(constant.MakeFromLiteral("1074025684", token.INT, 0)),
		"TUNSETSTEERINGEBPF":                reflect.ValueOf(constant.MakeFromLiteral("2147767520", token.INT, 0)),
		"TUNSETTXFILTER":                    reflect.ValueOf(constant.MakeFromLiteral("1074025681", token.INT, 0)),
		"TUNSETVNETBE":                      reflect.ValueOf(constant.MakeFromLiteral("1074025694", token.INT, 0)),
		"TUNSETVNETHDRSZ":                   reflect.ValueOf(constant.MakeFromLiteral("1074025688", token.INT, 0)),
		"TUNSETVNETLE":                      reflect.ValueOf(constant.MakeFromLiteral("1074025692", token.INT, 0)),
		"Tee":                               reflect.ValueOf(syscall.Tee),
		"Tgkill":                            reflect.ValueOf(syscall.Tgkill),
		"Time":                              reflect.ValueOf(syscall.Time),
		"Times":                             reflect.ValueOf(syscall.Times),
		"TimespecToNsec":                    reflect.ValueOf(syscall.TimespecToNsec),
		"TimevalToNsec":                     reflect.ValueOf(syscall.TimevalToNsec),
		"Truncate":                          reflect.ValueOf(syscall.Truncate),
		"Umask":                             reflect.ValueOf(syscall.Umask),
		"Uname":                             reflect.ValueOf(syscall.Uname),
		"UnixCredentials":                   reflect.ValueOf(syscall.UnixCredentials),
		"UnixRights":                        reflect.ValueOf(syscall.UnixRights),
		"Unlink":                            reflect.ValueOf(syscall.Unlink),
		"Unlinkat":                          reflect.ValueOf(syscall.Unlinkat),
		"Unmount":                           reflect.ValueOf(syscall.Unmount),
		"Unsetenv":                          reflect.ValueOf(syscall.Unsetenv),
		"Unshare":                           reflect.ValueOf(syscall.Unshare),
		"Utime":                             reflect.ValueOf(syscall.Utime),
		"Utimes":                            reflect.ValueOf(syscall.Utimes),
		"UtimesNano":                        reflect.ValueOf(syscall.UtimesNano),
		"VDISCARD":                          reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"VEOF":                              reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"VEOL":                              reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"VEOL2":                             reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"VERASE":                            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"VINTR":                             reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"VKILL":                             reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"VLNEXT":                            reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"VMIN":                              reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"VQUIT":                             reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"VREPRINT":                          reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"VSTART":                            reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"VSTOP":                             reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"VSUSP":                             reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"VSWTC":                             reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"VT0":                               reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"VT1":                               reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"VTDLY":                             reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"VTIME":                             reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"VWERASE":                           reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"WALL":                              reflect.ValueOf(constant.MakeFromLiteral("1073741824", token.INT, 0)),
		"WCLONE":                            reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"WCONTINUED":                        reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"WEXITED":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"WNOHANG":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"WNOTHREAD":                         reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"WNOWAIT":                           reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"WORDSIZE":                          reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"WSTOPPED":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"WUNTRACED":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"Wait4":                             reflect.ValueOf(syscall.Wait4),
		"Write":                             reflect.ValueOf(syscall.Write),
		"XCASE":                             reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),

		// type definitions
		"Cmsghdr":              reflect.ValueOf((*syscall.Cmsghdr)(nil)),
		"Conn":                 reflect.ValueOf((*syscall.Conn)(nil)),
		"Credential":           reflect.ValueOf((*syscall.Credential)(nil)),
		"Dirent":               reflect.ValueOf((*syscall.Dirent)(nil)),
		"EpollEvent":           reflect.ValueOf((*syscall.EpollEvent)(nil)),
		"Errno":                reflect.ValueOf((*syscall.Errno)(nil)),
		"FdSet":                reflect.ValueOf((*syscall.FdSet)(nil)),
		"Flock_t":              reflect.ValueOf((*syscall.Flock_t)(nil)),
		"Fsid":                 reflect.ValueOf((*syscall.Fsid)(nil)),
		"ICMPv6Filter":         reflect.ValueOf((*syscall.ICMPv6Filter)(nil)),
		"IPMreq":               reflect.ValueOf((*syscall.IPMreq)(nil)),
		"IPMreqn":              reflect.ValueOf((*syscall.IPMreqn)(nil)),
		"IPv6MTUInfo":          reflect.ValueOf((*syscall.IPv6MTUInfo)(nil)),
		"IPv6Mreq":             reflect.ValueOf((*syscall.IPv6Mreq)(nil)),
		"IfAddrmsg":            reflect.ValueOf((*syscall.IfAddrmsg)(nil)),
		"IfInfomsg":            reflect.ValueOf((*syscall.IfInfomsg)(nil)),
		"Inet4Pktinfo":         reflect.ValueOf((*syscall.Inet4Pktinfo)(nil)),
		"Inet6Pktinfo":         reflect.ValueOf((*syscall.Inet6Pktinfo)(nil)),
		"InotifyEvent":         reflect.ValueOf((*syscall.InotifyEvent)(nil)),
		"Iovec":                reflect.ValueOf((*syscall.Iovec)(nil)),
		"Linger":               reflect.ValueOf((*syscall.Linger)(nil)),
		"Msghdr":               reflect.ValueOf((*syscall.Msghdr)(nil)),
		"NetlinkMessage":       reflect.ValueOf((*syscall.NetlinkMessage)(nil)),
		"NetlinkRouteAttr":     reflect.ValueOf((*syscall.NetlinkRouteAttr)(nil)),
		"NetlinkRouteRequest":  reflect.ValueOf((*syscall.NetlinkRouteRequest)(nil)),
		"NlAttr":               reflect.ValueOf((*syscall.NlAttr)(nil)),
		"NlMsgerr":             reflect.ValueOf((*syscall.NlMsgerr)(nil)),
		"NlMsghdr":             reflect.ValueOf((*syscall.NlMsghdr)(nil)),
		"ProcAttr":             reflect.ValueOf((*syscall.ProcAttr)(nil)),
		"RawConn":              reflect.ValueOf((*syscall.RawConn)(nil)),
		"RawSockaddr":          reflect.ValueOf((*syscall.RawSockaddr)(nil)),
		"RawSockaddrAny":       reflect.ValueOf((*syscall.RawSockaddrAny)(nil)),
		"RawSockaddrInet4":     reflect.ValueOf((*syscall.RawSockaddrInet4)(nil)),
		"RawSockaddrInet6":     reflect.ValueOf((*syscall.RawSockaddrInet6)(nil)),
		"RawSockaddrLinklayer": reflect.ValueOf((*syscall.RawSockaddrLinklayer)(nil)),
		"RawSockaddrNetlink":   reflect.ValueOf((*syscall.RawSockaddrNetlink)(nil)),
		"RawSockaddrUnix":      reflect.ValueOf((*syscall.RawSockaddrUnix)(nil)),
		"Rlimit":               reflect.ValueOf((*syscall.Rlimit)(nil)),
		"RtAttr":               reflect.ValueOf((*syscall.RtAttr)(nil)),
		"RtGenmsg":             reflect.ValueOf((*syscall.RtGenmsg)(nil)),
		"RtMsg":                reflect.ValueOf((*syscall.RtMsg)(nil)),
		"RtNexthop":            reflect.ValueOf((*syscall.RtNexthop)(nil)),
		"Rusage":               reflect.ValueOf((*syscall.Rusage)(nil)),
		"Signal":               reflect.ValueOf((*syscall.Signal)(nil)),
		"SockFilter":           reflect.ValueOf((*syscall.SockFilter)(nil)),
		"SockFprog":            reflect.ValueOf((*syscall.SockFprog)(nil)),
		"Sockaddr":             reflect.ValueOf((*syscall.Sockaddr)(nil)),
		"SockaddrInet4":        reflect.ValueOf((*syscall.SockaddrInet4)(nil)),
		"SockaddrInet6":        reflect.ValueOf((*syscall.SockaddrInet6)(nil)),
		"SockaddrLinklayer":    reflect.ValueOf((*syscall.SockaddrLinklayer)(nil)),
		"SockaddrNetlink":      reflect.ValueOf((*syscall.SockaddrNetlink)(nil)),
		"SockaddrUnix":         reflect.ValueOf((*syscall.SockaddrUnix)(nil)),
		"SocketControlMessage": reflect.ValueOf((*syscall.SocketControlMessage)(nil)),
		"Stat_t":               reflect.ValueOf((*syscall.Stat_t)(nil)),
		"Statfs_t":             reflect.ValueOf((*syscall.Statfs_t)(nil)),
		"SysProcAttr":          reflect.ValueOf((*syscall.SysProcAttr)(nil)),
		"SysProcIDMap":         reflect.ValueOf((*syscall.SysProcIDMap)(nil)),
		"Sysinfo_t":            reflect.ValueOf((*syscall.Sysinfo_t)(nil)),
		"TCPInfo":              reflect.ValueOf((*syscall.TCPInfo)(nil)),
		"Termios":              reflect.ValueOf((*syscall.Termios)(nil)),
		"Time_t":               reflect.ValueOf((*syscall.Time_t)(nil)),
		"Timespec":             reflect.ValueOf((*syscall.Timespec)(nil)),
		"Timeval":              reflect.ValueOf((*syscall.Timeval)(nil)),
		"Timex":                reflect.ValueOf((*syscall.Timex)(nil)),
		"Tms":                  reflect.ValueOf((*syscall.Tms)(nil)),
		"Ucred":                reflect.ValueOf((*syscall.Ucred)(nil)),
		"Ustat_t":              reflect.ValueOf((*syscall.Ustat_t)(nil)),
		"Utimbuf":              reflect.ValueOf((*syscall.Utimbuf)(nil)),
		"Utsname":              reflect.ValueOf((*syscall.Utsname)(nil)),
		"WaitStatus":           reflect.ValueOf((*syscall.WaitStatus)(nil)),

		// interface wrapper definitions
		"_Conn":     reflect.ValueOf((*_syscall_Conn)(nil)),
		"_RawConn":  reflect.ValueOf((*_syscall_RawConn)(nil)),
		"_Sockaddr": reflect.ValueOf((*_syscall_Sockaddr)(nil)),
	}
}

// _syscall_Conn is an interface wrapper for Conn type
type _syscall_Conn struct {
	IValue       interface{}
	WSyscallConn func() (syscall.RawConn, error)
}

func (W _syscall_Conn) SyscallConn() (syscall.RawConn, error) { return W.WSyscallConn() }

// _syscall_RawConn is an interface wrapper for RawConn type
type _syscall_RawConn struct {
	IValue   interface{}
	WControl func(f func(fd uintptr)) error
	WRead    func(f func(fd uintptr) (done bool)) error
	WWrite   func(f func(fd uintptr) (done bool)) error
}

func (W _syscall_RawConn) Control(f func(fd uintptr)) error           { return W.WControl(f) }
func (W _syscall_RawConn) Read(f func(fd uintptr) (done bool)) error  { return W.WRead(f) }
func (W _syscall_RawConn) Write(f func(fd uintptr) (done bool)) error { return W.WWrite(f) }

// _syscall_Sockaddr is an interface wrapper for Sockaddr type
type _syscall_Sockaddr struct {
	IValue interface{}
}
